%--------------------------------------------------------------------------
% File     : COL053-1 : TPTP v2.7.0. Released v1.0.0.
% Domain   : Combinatory Logic
% Problem  : An Exercise in Composition
% Version  : Especial.
% English  : For all birds x and y, there exists a bird z that composes 
%            x with y for all birds w. Prove that for all birds x, y, and 
%            z, there exists a bird u such that for all w, uw = x(y(zw)).

% Refs     : [Smu85] Smullyan (1978), To Mock a Mocking Bird and Other Logi
% Source   : [ANL]
% Names    : bird5.ver1.in [ANL]

% Status   : unsatisfiable
% Rating   : 0.00 v2.0.0
% Syntax   : Number of clauses    :   10 (   0 non-Horn;   3 unit;   4 RR)
%            Number of literals   :   18 (  18 equality)
%            Maximal clause size  :    3 (   1 average)
%            Number of predicates :    1 (   0 propositional; 2-2 arity)
%            Number of functors   :    6 (   3 constant; 0-2 arity)
%            Number of variables  :   24 (   0 singleton)
%            Maximal term depth   :    5 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include the axioms of equality 
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
%----For all birds x and y, there exists a bird z that composes x with 
%----y for all birds w.
%----   FAx FAy TEz FAw [response(z,w) = response(x,response(y,w))].
%----   response(comp(x,y),w) = response(x,response(y,w)). 
input_clause(composer_exists,axiom,
    [++equal(response(compose(X,Y),W),response(X,response(Y,W)))]).

input_clause(compose_substitution1,axiom,
    [--equal(A,B),
     ++equal(compose(A,C),compose(B,C))]).

input_clause(compose_substitution2,axiom,
    [--equal(D,E),
     ++equal(compose(F,D),compose(F,E))]).

input_clause(response_substitution1,axiom,
    [--equal(G,H),
     ++equal(response(G,I),response(H,I))]).

input_clause(response_substitution2,axiom,
    [--equal(J,K),
     ++equal(response(L,J),response(L,K))]).

input_clause(f_substitutivity1,axiom,
    [--equal(G,H),
     ++equal(f(G),f(H))]).

%----Hypothesis: For all birds x, y, and z, there exists a bird u such 
%----that for all w, uw = x(y(zw)).
%----Finding clause (using xy to replace response(x,y)):
%----  - (FAx FAy FAz TEu FAw (uw = x(y(zw)))).
%----  TEx TEy TEz FAu TEw -(uw = x(y(zw))).
%----  Letting w = f(u), x = A, y = B, and z = C,
%----  -[(u)f(u) = A(B((C)f(u)))].
input_clause(prove_bird_exists,conjecture,
    [--equal(response(U,f(U)),response(a,response(b,response(c,f(U)))))]).
%--------------------------------------------------------------------------
