%--------------------------------------------------------------------------
% File     : GRP025-1 : TPTP v2.7.0. Bugfixed v1.2.1.
% Domain   : Group Theory (Named groups)
% Problem  : All groups of order 2 are isomorphic
% Version  : [MOW76] axioms.
%            Theorem formulation : Does not prove full generality.
% English  : If G1 has exactly two elements and G2 has exactly two 
%            elements, then there exists an isomorphism [a one-to-one and 
%            onto homomorphism] between them.

% Refs     : [MOW76] McCharen et al. (1976), Problems and Experiments for a
% Source   : [ANL]
% Names    : G8 [MOW76]

% Status   : unsatisfiable
% Rating   : 0.55 v2.7.0, 0.58 v2.6.0, 0.44 v2.5.0, 0.36 v2.4.0, 0.25 v2.3.0, 0.50 v2.2.1, 0.57 v2.2.0, 0.80 v2.1.0, 0.50 v2.0.0
% Syntax   : Number of clauses    :   48 (   2 non-Horn;  25 unit;  37 RR)
%            Number of literals   :   87 (  33 equality)
%            Maximal clause size  :    4 (   2 average)
%            Number of predicates :    3 (   0 propositional; 2-4 arity)
%            Number of functors   :   13 (   9 constant; 0-3 arity)
%            Number of variables  :   92 (   0 singleton)
%            Maximal term depth   :    2 (   1 average)

% Comments : In order to prove the theorem, the group tables and a
%            particular homomorphism are specified, and the contradiction
%            comes from the fact that this is the actual isomorphism. Not
%            only is this formulation cheating, but also it does not prove
%            the theorem in full generality.
%          : A substitution axiom, missing in the ANL presentation, is
%            included.
% Bugfixes : v1.2.1 - Bugfix in GRP006-0.ax.
%--------------------------------------------------------------------------
%----Include equality axioms 
include('Axioms/EQU001-0.ax').
%----Include the axioms for named groups 
include('Axioms/GRP006-0.ax').
%----Include the equality axioms for named groups 
include('Axioms/GRP006-0.eq').
%--------------------------------------------------------------------------
%----Definition of the two groups 
input_clause(a_member_of_group1,hypothesis,
    [++group_member(a,g1)]).

input_clause(b_member_of_group1,hypothesis,
    [++group_member(b,g1)]).

input_clause(c_member_of_group2,hypothesis,
    [++group_member(c,g2)]).

input_clause(d_member_of_group2,hypothesis,
    [++group_member(d,g2)]).

input_clause(a_and_b_only_members_of_group1,hypothesis,
    [--group_member(X,g1),
     ++equal(X,a),
     ++equal(X,b)]).

input_clause(c_and_d_only_members_of_group2,hypothesis,
    [--group_member(X,g2),
     ++equal(X,c),
     ++equal(X,d)]).

input_clause(a_times_a_is_a,hypothesis,
    [++product(g1,a,a,a)]).

input_clause(a_times_b_is_b,hypothesis,
    [++product(g1,a,b,b)]).

input_clause(b_times_a_is_b,hypothesis,
    [++product(g1,b,a,b)]).

input_clause(b_times_b_is_a,hypothesis,
    [++product(g1,b,b,a)]).

input_clause(c_times_c_is_c,hypothesis,
    [++product(g2,c,c,c)]).

input_clause(c_times_d_is_d,hypothesis,
    [++product(g2,c,d,d)]).

input_clause(d_times_c_is_d,hypothesis,
    [++product(g2,d,c,d)]).

input_clause(d_times_d_is_c,hypothesis,
    [++product(g2,d,d,c)]).

%----Definition of the isomorphism 
input_clause(a_maps_to_c,hypothesis,
    [++equal(an_isomorphism(a),c)]).

input_clause(b_maps_to_d,hypothesis,
    [++equal(an_isomorphism(b),d)]).

%----Substitution for the isomophism 
input_clause(an_isomorphism_substitution1,axiom,
    [--equal(X,Y),
     ++equal(an_isomorphism(X),an_isomorphism(Y))]).

%----Denial that the isomorphism is indeed one 
input_clause(d1_member_of_group1,hypothesis,
    [++group_member(d1,g1)]).

input_clause(d2_member_of_group1,hypothesis,
    [++group_member(d2,g1)]).

input_clause(d3_member_of_group1,hypothesis,
    [++group_member(d3,g1)]).

input_clause(d1_times_d2_is_d3,hypothesis,
    [++product(g1,d1,d2,d3)]).

input_clause(prove_product_holds_in_group2,conjecture,
    [--product(g2,an_isomorphism(d1),an_isomorphism(d2),
an_isomorphism(d3))]).
%--------------------------------------------------------------------------
