%--------------------------------------------------------------------------
% File     : GRP026-3 : TPTP v2.7.0. Bugfixed v2.0.0.
% Domain   : Group Theory (Named groups)
% Problem  : All groups of order 3 are isomorphic
% Version  : [MOW76] axioms : Incomplete.
%            Theorem formulation : Does not prove full generality.
% English  : If G1 and G2 each have exactly three elements, then there 
%            exists an isomorphism [a one-to-one and onto homomorphism] 
%            between them.

% Refs     : [MOW76] McCharen et al. (1976), Problems and Experiments for a
% Source   : [ANL]
% Names    : order3.ver3.in [ANL]

% Status   : satisfiable
% Rating   : 0.86 v2.7.0, 0.80 v2.6.0, 1.00 v2.1.0
% Syntax   : Number of clauses    :   60 (   2 non-Horn;  38 unit;  49 RR)
%            Number of literals   :  100 (   0 equality)
%            Maximal clause size  :    4 (   2 average)
%            Number of predicates :    3 (   0 propositional; 2-4 arity)
%            Number of functors   :   15 (  11 constant; 0-3 arity)
%            Number of variables  :   90 (   0 singleton)
%            Maximal term depth   :    2 (   1 average)

% Comments : In order to prove the theorem, the group tables and a
%            particular homomorphism are specified, and the contradiction
%            comes from the fact that this is the actual isomorphism. Not
%            only is this formulation cheating, but also it does not prove
%            the theorem in full generality.
%          : Missing an_isomorphism subsitution axioms.
% Bugfixes : v1.2.1 - Bugfix in GRP006-0.ax.
%          : v2.0.0 - Clause prove_product_holds_in_group2 fixed.
%--------------------------------------------------------------------------
%----Don't include equality axioms because it's incomplete
%include('Axioms/EQU001-0.ax').
%----Include the axioms for named groups 
%include('Axioms/GRP006-0.ax').
%----Include the equality axioms for named groups 
%include('Axioms/GRP006-0.eq').
%--------------------------------------------------------------------------
input_clause(reflexivity,axiom,
    [++equalish(X,X)]).

input_clause(symmetry,axiom,
    [--equalish(X,Y),
     ++equalish(Y,X)]).

input_clause(transitivity,axiom,
    [--equalish(X,Y),
     --equalish(Y,Z),
     ++equalish(X,Z)]).

input_clause(identity_in_group,axiom,
    [++group_member(identity_for(Xg),Xg)]).

input_clause(left_identity,axiom,
    [++product(Xg,identity_for(Xg),X,X)]).

input_clause(right_identity,axiom,
    [++product(Xg,X,identity_for(Xg),X)]).

input_clause(inverse_in_group,axiom,
    [--group_member(X,Xg),
     ++group_member(inverse(Xg,X),Xg)]).

input_clause(left_inverse,axiom,
    [++product(Xg,inverse(Xg,X),X,identity_for(Xg))]).

input_clause(right_inverse,axiom,
    [++product(Xg,X,inverse(Xg,X),identity_for(Xg))]).

%----These axioms are called closure or totality in some axiomatisations 
input_clause(total_function1_1,axiom,
    [--group_member(X,Xg),
     --group_member(Y,Xg),
     ++product(Xg,X,Y,multiply(Xg,X,Y))]).

input_clause(total_function1_2,axiom,
    [--group_member(X,Xg),
     --group_member(Y,Xg),
     ++group_member(multiply(Xg,X,Y),Xg)]).

%----This axiom is called well_definedness in some axiomatisations 
input_clause(total_function2,axiom,
    [--product(Xg,X,Y,Z),
     --product(Xg,X,Y,W),
     ++equalish(W,Z)]).

input_clause(associativity1,axiom,
    [--product(Xg,X,Y,Xy),
     --product(Xg,Y,Z,Yz),
     --product(Xg,Xy,Z,Xyz),
     ++product(Xg,X,Yz,Xyz)]).

input_clause(associativity2,axiom,
    [--product(Xg,X,Y,Xy),
     --product(Xg,Y,Z,Yz),
     --product(Xg,X,Yz,Xyz),
     ++product(Xg,Xy,Z,Xyz)]).

input_clause(product_substitution1,axiom,
    [--equalish(Xg,Yg),
     --product(Xg,X,Y,Z),
     ++product(Yg,X,Y,Z)]).

input_clause(product_substitution2,axiom,
    [--equalish(X,Y),
     --product(Xg,X,Z,W),
     ++product(Xg,Y,Z,W)]).

input_clause(product_substitution3,axiom,
    [--equalish(X,Y),
     --product(Xg,W,X,Z),
     ++product(Xg,W,Y,Z)]).

input_clause(product_substitution4,axiom,
    [--equalish(X,Y),
     --product(Xg,W,Z,X),
     ++product(Xg,W,Z,Y)]).

input_clause(multiply_substitution1,axiom,
    [--equalish(Xg,Yg),
     ++equalish(multiply(Xg,X,Y),multiply(Yg,X,Y))]).

input_clause(multiply_substitution2,axiom,
    [--equalish(X,Y),
     ++equalish(multiply(Xg,X,Z),multiply(Xg,Y,Z))]).

input_clause(multiply_substitution3,axiom,
    [--equalish(X,Y),
     ++equalish(multiply(Xg,Z,X),multiply(Xg,Z,Y))]).

input_clause(inverse_substitution1,axiom,
    [--equalish(Xg,Yg),
     ++equalish(inverse(Xg,X),inverse(Yg,X))]).

input_clause(inverse_substitution2,axiom,
    [--equalish(X,Y),
     ++equalish(inverse(Xg,X),inverse(Xg,Y))]).

input_clause(group_member_substitution1,axiom,
    [--equalish(Xg,Yg),
     --group_member(X,Xg),
     ++group_member(X,Yg)]).

input_clause(group_member_substitution2,axiom,
    [--equalish(X,Y),
     --group_member(X,Xg),
     ++group_member(Y,Xg)]).

input_clause(identity_substitution,axiom,
    [--equalish(Xg,Yg),
     ++equalish(identity_for(Xg),identity_for(Yg))]).

%----Definition of the two groups 
input_clause(a_in_group1,hypothesis,
    [++group_member(a,g1)]).

input_clause(b_in_group1,hypothesis,
    [++group_member(b,g1)]).

input_clause(c_in_group1,hypothesis,
    [++group_member(c,g1)]).

input_clause(f_in_group2,hypothesis,
    [++group_member(f,g2)]).

input_clause(g_in_group2,hypothesis,
    [++group_member(g,g2)]).

input_clause(h_in_group2,hypothesis,
    [++group_member(h,g2)]).

input_clause(all_of_group1,hypothesis,
    [--group_member(X,g1),
     ++equalish(X,a),
     ++equalish(X,b),
     ++equalish(X,c)]).

input_clause(all_of_group2,hypothesis,
    [--group_member(X,g2),
     ++equalish(X,f),
     ++equalish(X,g),
     ++equalish(X,h)]).

input_clause(a_times_a_is_a,hypothesis,
    [++product(g1,a,a,a)]).

input_clause(a_times_b_is_b,hypothesis,
    [++product(g1,a,b,b)]).

input_clause(b_times_a_is_b,hypothesis,
    [++product(g1,b,a,b)]).

input_clause(a_times_c_is_c,hypothesis,
    [++product(g1,a,c,c)]).

input_clause(c_times_a_is_c,hypothesis,
    [++product(g1,c,a,c)]).

input_clause(b_times_b_is_c,hypothesis,
    [++product(g1,b,b,c)]).

input_clause(b_times_c_is_a,hypothesis,
    [++product(g1,b,c,a)]).

input_clause(c_times_b_is_a,hypothesis,
    [++product(g1,c,b,a)]).

input_clause(c_times_c_is_b,hypothesis,
    [++product(g1,c,c,b)]).

input_clause(f_times_f_is_f,hypothesis,
    [++product(g2,f,f,f)]).

input_clause(f_times_g_is_g,hypothesis,
    [++product(g2,f,g,g)]).

input_clause(g_times_f_is_g,hypothesis,
    [++product(g2,g,f,g)]).

input_clause(f_times_h_is_h,hypothesis,
    [++product(g2,f,h,h)]).

input_clause(h_times_f_is_h,hypothesis,
    [++product(g2,h,f,h)]).

input_clause(g_times_g_is_h,hypothesis,
    [++product(g2,g,g,h)]).

input_clause(g_times_h_is_f,hypothesis,
    [++product(g2,g,h,f)]).

input_clause(h_times_g_is_f,hypothesis,
    [++product(g2,h,g,f)]).

input_clause(h_times_h_is_g,hypothesis,
    [++product(g2,h,h,g)]).

%----Definition of an isomorphism 
input_clause(a_maps_to_f,hypothesis,
    [++equalish(an_isomorphism(a),f)]).

input_clause(b_maps_to_g,hypothesis,
    [++equalish(an_isomorphism(b),g)]).

input_clause(c_maps_to_h,hypothesis,
    [++equalish(an_isomorphism(c),h)]).

%----Denial that the isomorphism is one 
input_clause(d1_in_group1,hypothesis,
    [++group_member(d1,g1)]).

input_clause(d2_in_group1,hypothesis,
    [++group_member(d2,g1)]).

input_clause(d3_in_group1,hypothesis,
    [++group_member(d3,g1)]).

input_clause(d1_times_d2_is_d3,hypothesis,
    [++product(g1,d1,d2,d3)]).

input_clause(prove_product_holds_in_group2,conjecture,
    [--product(g2,an_isomorphism(d1),an_isomorphism(d2),
an_isomorphism(d3))]).
%--------------------------------------------------------------------------
