%--------------------------------------------------------------------------
% File     : HWV003-2 : TPTP v2.7.0. Released v2.7.0.
% Domain   : Hardware Verification
% Problem  : One bit Full Adder
% Version  : Especial.
% English  : Prove that the given implementation of a one-bit full adder 
%            using only NAND gates is correct

% Refs     : [WO+92] Wos et al. (1992), Automated Reasoning: Introduction a
%          : [Bur]   Burris, Comments on Boolean Algebra
%          : [Bur98] Burris (1998), Logic for Mathematics and Computer Scie
%          : [Bou03] Boule (2003), Email to G. Sutcliffe
% Source   : [Bou03]
% Names    : 

% Status   : unsatisfiable
% Rating   : 0.00 v2.7.0
% Syntax   : Number of clauses    :   46 (   0 non-Horn;  36 unit;  17 RR)
%            Number of literals   :   57 (  57 equality)
%            Maximal clause size  :    3 (   1 average)
%            Number of predicates :    1 (   0 propositional; 2-2 arity)
%            Number of functors   :   20 (  16 constant; 0-2 arity)
%            Number of variables  :   66 (   4 singleton)
%            Maximal term depth   :    4 (   2 average)

% Comments : This is an alternate encoding of HWV003-1.p. In reality, 
%            one could use a propositional logic encoding of the problem
%            in order for the problem to be fully-decidable and for run- 
%            times to be much quicker. 
%--------------------------------------------------------------------------
%----Include axioms of equality
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
%----Boolean logic axioms (not a minimal set of axioms)
input_clause(or_commutative,axiom,
    [++equal(or(X,Y),or(Y,X))]).

input_clause(and_commutative,axiom,
    [++equal(and(X,Y),and(Y,X))]).

input_clause(or_associative,axiom,
    [++equal(or(or(X,Y),Z),or(X,or(Y,Z)))]).

input_clause(and_associative,axiom,
    [++equal(and(and(X,Y),Z),and(X,and(Y,Z)))]).

input_clause(or_identity,axiom,
    [++equal(or(X,ll0),X)]).

input_clause(and_identity,axiom,
    [++equal(and(X,ll1),X)]).

input_clause(or_distributive,axiom,
    [++equal(and(X,or(Y,Z)),or(and(X,Y),and(X,Z)))]).

input_clause(and_distributive,axiom,
    [++equal(or(X,and(Y,Z)),and(or(X,Y),or(X,Z)))]).

input_clause(or_complement,axiom,
    [++equal(or(X,not(X)),ll1)]).

input_clause(and_complement,axiom,
    [++equal(and(X,not(X)),ll0)]).

input_clause(or_idempotent,axiom,
    [++equal(or(X,X),X)]).

input_clause(and_idempotent,axiom,
    [++equal(and(X,X),X)]).

input_clause(not_involution,axiom,
    [++equal(not(not(X)),X)]).

input_clause(ll0_inverse,axiom,
    [++equal(not(ll0),ll1)]).

input_clause(ll1_inverse,axiom,
    [++equal(not(ll1),ll0)]).

input_clause(or_boundedness,axiom,
    [++equal(or(X,ll1),ll1)]).

input_clause(and_boundedness,axiom,
    [++equal(and(X,ll0),ll0)]).

input_clause(or_absorption,axiom,
    [++equal(or(X,and(X,Y)),X)]).

input_clause(and_absorption,axiom,
    [++equal(and(X,or(X,Y)),X)]).

input_clause(or_demorgan,axiom,
    [++equal(not(or(X,Y)),and(not(X),not(Y)))]).

input_clause(and_demorgan,axiom,
    [++equal(not(and(X,Y)),or(not(X),not(Y)))]).

%----Extra substitution axioms
input_clause(and_substitution1,axiom,
    [--equal(X,Y),
     ++equal(and(X,Z),and(Y,Z))]).

input_clause(and_substitution2,axiom,
    [--equal(X,Y),
     ++equal(and(Z,X),and(Z,Y))]).

input_clause(or_substitution1,axiom,
    [--equal(X,Y),
     ++equal(or(X,Z),or(Y,Z))]).

input_clause(or_substitution2,axiom,
    [--equal(X,Y),
     ++equal(or(Z,X),or(Z,Y))]).

input_clause(not_substitution,axiom,
    [--equal(X,Y),
     ++equal(not(X),not(Y))]).

%----full_adder problem:
input_clause(xor_definition,axiom,
    [++equal(or(and(not(X),Y),and(X,not(Y))),xor(X,Y))]).

input_clause(xor_commutative,axiom,
    [++equal(xor(X,Y),xor(Y,X))]).

input_clause(xor_associative,axiom,
    [++equal(xor(X,xor(Y,Z)),xor(xor(X,Y),Z))]).

input_clause(xor_substitution1,axiom,
    [--equal(X,Y),
     ++equal(xor(X,Z),xor(Y,Z))]).

input_clause(xor_substitution2,axiom,
    [--equal(X,Y),
     ++equal(xor(Z,X),xor(Z,Y))]).

input_clause(sum_def,conjecture,
    [++equal(xor(xor(a,b),cin),sum_def)]).

input_clause(carry_def,conjecture,
    [++equal(or(and(cin,or(a,b)),and(not(cin),and(a,b))),carry_def)]).

input_clause(t1,conjecture,
    [++equal(not(and(a,b)),t1)]).

input_clause(t2,conjecture,
    [++equal(not(and(a,t1)),t2)]).

input_clause(t3,conjecture,
    [++equal(not(and(b,t1)),t3)]).

input_clause(t4,conjecture,
    [++equal(not(and(t2,t3)),t4)]).

input_clause(t5,conjecture,
    [++equal(not(and(t4,cin)),t5)]).

input_clause(t6,conjecture,
    [++equal(not(and(t4,t5)),t6)]).

input_clause(t7,conjecture,
    [++equal(not(and(t5,cin)),t7)]).

input_clause(sum,conjecture,
    [++equal(not(and(t6,t7)),sum)]).

input_clause(carry,conjecture,
    [++equal(not(and(t1,t5)),carry)]).

input_clause(prove_circuit,conjecture,
    [--equal(sum,sum_def),
     --equal(carry,carry_def)]).
%--------------------------------------------------------------------------
