%--------------------------------------------------------------------------
% File     : MGT019-2 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Growth rate of EPs exceeds that of FMs in stable environments
% Version  : [PM93] axioms.
% English  : The growth rate of efficent producers exceeds the growth rate 
%            of first movers past a certain time in stable environments.

% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [PB+94] Peli et al. (1994), A Logical Approach to Formalizing
% Source   : [TPTP]
% Names    : 

% Status   : satisfiable
% Rating   : 0.00 v2.5.0, 0.17 v2.4.0
% Syntax   : Number of clauses    :   33 (   1 non-Horn;   6 unit;  26 RR)
%            Number of literals   :   79 (  31 equality)
%            Maximal clause size  :    5 (   2 average)
%            Number of predicates :    7 (   0 propositional; 1-4 arity)
%            Number of functors   :   10 (   5 constant; 0-2 arity)
%            Number of variables  :   75 (   0 singleton)
%            Maximal term depth   :    3 (   1 average)

% Comments : There is no MGT019+1 as Kamps did not send it to me.
%          : Created with tptp2X -f tptp -t clausify:otter MGT019+2.p 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
input_clause(disbanding_rate_substitution_1_4,axiom,
    [--equal(A,B),
     ++equal(disbanding_rate(A,C),disbanding_rate(B,C))]).

input_clause(disbanding_rate_substitution_2_5,axiom,
    [--equal(A,B),
     ++equal(disbanding_rate(C,A),disbanding_rate(C,B))]).

input_clause(founding_rate_substitution_1_6,axiom,
    [--equal(A,B),
     ++equal(founding_rate(A,C),founding_rate(B,C))]).

input_clause(founding_rate_substitution_2_7,axiom,
    [--equal(A,B),
     ++equal(founding_rate(C,A),founding_rate(C,B))]).

input_clause(growth_rate_substitution_1_8,axiom,
    [--equal(A,B),
     ++equal(growth_rate(A,C),growth_rate(B,C))]).

input_clause(growth_rate_substitution_2_9,axiom,
    [--equal(A,B),
     ++equal(growth_rate(C,A),growth_rate(C,B))]).

input_clause(environment_substitution_1_10,axiom,
    [--equal(A,B),
     --environment(A),
     ++environment(B)]).

input_clause(greater_substitution_1_11,axiom,
    [--equal(A,B),
     --greater(A,C),
     ++greater(B,C)]).

input_clause(greater_substitution_2_12,axiom,
    [--equal(A,B),
     --greater(C,A),
     ++greater(C,B)]).

input_clause(greater_or_equal_substitution_1_13,axiom,
    [--equal(A,B),
     --greater_or_equal(A,C),
     ++greater_or_equal(B,C)]).

input_clause(greater_or_equal_substitution_2_14,axiom,
    [--equal(A,B),
     --greater_or_equal(C,A),
     ++greater_or_equal(C,B)]).

input_clause(in_environment_substitution_1_15,axiom,
    [--equal(A,B),
     --in_environment(A,C),
     ++in_environment(B,C)]).

input_clause(in_environment_substitution_2_16,axiom,
    [--equal(A,B),
     --in_environment(C,A),
     ++in_environment(C,B)]).

input_clause(stable_substitution_1_17,axiom,
    [--equal(A,B),
     --stable(A),
     ++stable(B)]).

input_clause(subpopulations_substitution_1_18,axiom,
    [--equal(A,B),
     --subpopulations(A,C,D,E),
     ++subpopulations(B,C,D,E)]).

input_clause(subpopulations_substitution_2_19,axiom,
    [--equal(A,B),
     --subpopulations(C,A,D,E),
     ++subpopulations(C,B,D,E)]).

input_clause(subpopulations_substitution_3_20,axiom,
    [--equal(A,B),
     --subpopulations(C,D,A,E),
     ++subpopulations(C,D,B,E)]).

input_clause(subpopulations_substitution_4_21,axiom,
    [--equal(A,B),
     --subpopulations(C,D,E,A),
     ++subpopulations(C,D,E,B)]).

input_clause(l2_22,axiom,
    [++environment(sk1)]).

input_clause(l2_23,axiom,
    [++subpopulations(first_movers,efficient_producers,sk1,sk2)]).

input_clause(l2_24,axiom,
    [--greater(disbanding_rate(first_movers,sk2),disbanding_rate(efficient_producers,sk2))]).

input_clause(mp_EP_lower_disbanding_rate_25,axiom,
    [--greater(disbanding_rate(first_movers,A),disbanding_rate(efficient_producers,A)),
     --greater_or_equal(founding_rate(efficient_producers,A),founding_rate(first_movers,A)),
     ++greater(growth_rate(efficient_producers,A),growth_rate(first_movers,A))]).

input_clause(mp_greater_or_equal_26,axiom,
    [--greater_or_equal(A,B),
     ++greater(A,B),
     ++equal(A,B)]).

input_clause(a8_27,hypothesis,
    [--environment(A),
     --stable(A),
     ++in_environment(A,sk3(A))]).

input_clause(a8_28,hypothesis,
    [--environment(A),
     --stable(A),
     --subpopulations(first_movers,efficient_producers,A,B),
     --greater_or_equal(B,sk3(A)),
     ++greater_or_equal(founding_rate(efficient_producers,B),founding_rate(first_movers,B))]).

input_clause(prove_l1_29,conjecture,
    [++environment(sk4)]).

input_clause(prove_l1_30,conjecture,
    [++stable(sk4)]).

input_clause(prove_l1_31,conjecture,
    [--in_environment(sk4,A),
     ++subpopulations(first_movers,efficient_producers,sk4,sk5(A))]).

input_clause(prove_l1_32,conjecture,
    [--in_environment(sk4,A),
     ++greater_or_equal(sk5(A),A)]).

input_clause(prove_l1_33,conjecture,
    [--in_environment(sk4,A),
     --greater(growth_rate(efficient_producers,sk5(A)),growth_rate(first_movers,sk5(A)))]).
%--------------------------------------------------------------------------
