%--------------------------------------------------------------------------
% File     : MGT021+1 : TPTP v2.7.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : Difference between disbanding rates does not decrease
% Version  : [PB+94] axioms.
% English  : The difference between the disbanding rates of first movers 
%            and efficient producers does not decrease with time. 

% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [PB+94] Peli et al. (1994), A Logical Approach to Formalizing
%          : [Kam95] Kamps (1995), Email to G. Sutcliffe
% Source   : [Kam95]
% Names    : LEMMA 3 [PM93]
%          : L3 [PB+94]

% Status   : theorem
% Rating   : 0.00 v2.5.0, 0.12 v2.4.0, 0.25 v2.3.0, 0.33 v2.2.1, 0.00 v2.1.0
% Syntax   : Number of formulae    :   33 (   1 unit)
%            Number of atoms       :   93 (  39 equality)
%            Maximal formula depth :    6 (   3 average)
%            Number of connectives :   64 (   4 ~  ;   1  |;  23  &)
%                                         (   0 <=>;  36 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    9 (   0 propositional; 1-4 arity)
%            Number of functors    :    8 (   3 constant; 0-2 arity)
%            Number of variables   :   91 (   0 singleton;  91 !;   0 ?)
%            Maximal term depth    :    3 (   1 average)

% Comments : Same as version with [PM93] axioms.
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(difference_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(difference(A,C),difference(B,C)) )   )).

input_formula(difference_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(difference(C,A),difference(C,B)) )   )).

input_formula(disbanding_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(disbanding_rate(A,C),disbanding_rate(B,C)) )   )).

input_formula(disbanding_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(disbanding_rate(C,A),disbanding_rate(C,B)) )   )).

input_formula(equilibrium_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(equilibrium(A),equilibrium(B)) )   )).

input_formula(number_of_organizations_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(number_of_organizations(A,C),
number_of_organizations(B,C)) )   )).

input_formula(number_of_organizations_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(number_of_organizations(C,A),
number_of_organizations(C,B)) )   )).

input_formula(resources_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(resources(A,C),resources(B,C)) )   )).

input_formula(resources_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(resources(C,A),resources(C,B)) )   )).

input_formula(constant_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & constant(A) )
     => constant(B) )   )).

input_formula(decreases_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & decreases(A) )
     => decreases(B) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(greater_or_equal_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(A,C) )
     => greater_or_equal(B,C) )   )).

input_formula(greater_or_equal_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(C,A) )
     => greater_or_equal(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(increases_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & increases(A) )
     => increases(B) )   )).

input_formula(subpopulations_substitution_1,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(A,C,D,E) )
     => subpopulations(B,C,D,E) )   )).

input_formula(subpopulations_substitution_2,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,A,D,E) )
     => subpopulations(C,B,D,E) )   )).

input_formula(subpopulations_substitution_3,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,A,E) )
     => subpopulations(C,D,B,E) )   )).

input_formula(subpopulations_substitution_4,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,E,A) )
     => subpopulations(C,D,E,B) )   )).

%----Problem axioms
%----MP. If first movers and efficient producers are present in an
%----environment  at a certain point of time, then this time-point belongs
%----to the the environment.
input_formula(mp_time_point_in_environment,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => in_environment(E,T) )   )).

%----MP. If first movers and efficient producers are present in an
%----environment  at a certain point of time, then then the environment
%----is not empty at this time.
input_formula(mp_environment_not_empty,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => greater(number_of_organizations(E,T),zero) )   )).

%----MP. If something increases, then it does not decrease.
input_formula(mp_increase_not_decrease,axiom,(
    ! [X] : 
      ( increases(X)
     => ~ decreases(X) )   )).

%----MP. on "greater or equal to"
input_formula(mp_greater_or_equal,axiom,(
    ! [X,Y] : 
      ( greater_or_equal(X,Y)
     => ( greater(X,Y)
        | equal(X,Y) ) )   )).

%----A3. Resource availability decreases until equilibrium is reached.
input_formula(a3,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater(number_of_organizations(E,T),zero) )
     => ( ( greater(equilibrium(E),T)
         => decreases(resources(E,T)) )
        & ( ~ greater(equilibrium(E),T)
         => constant(resources(E,T)) ) ) )   )).

%----L4. A decreasing resource availability affects the disbanding rate of
%----first movers more than the disbanding rate of efficient producers.
input_formula(l4,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => ( ( decreases(resources(E,T))
         => increases(difference(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T))) )
        & ( constant(resources(E,T))
         => ~ decreases(difference(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T))) ) ) )   )).

%----GOAL: L3. The difference between the disbanding rates of first movers 
%----and efficient producers does not decrease.
input_formula(prove_l3,conjecture,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => ~ decreases(difference(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T))) )   )).
%--------------------------------------------------------------------------
