%--------------------------------------------------------------------------
% File     : MGT033+1 : TPTP v2.7.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : Selection favors FMs above EPs until EPs appear
% Version  : [PB+94] axioms : Reduced & Augmented > Complete.
% English  : Selection favors first movers above efficient producers 
%            until the appearance of efficient producers. 

% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [Kam95] Kamps (1995), Email to G. Sutcliffe
% Source   : [Kam95]
% Names    : 

% Status   : satisfiable
% Rating   : 0.17 v2.7.0, 0.33 v2.6.0, 0.00 v2.5.0, 0.33 v2.4.0, 0.00 v2.1.0
% Syntax   : Number of formulae    :   37 (   1 unit)
%            Number of atoms       :  112 (  39 equality)
%            Maximal formula depth :    7 (   4 average)
%            Number of connectives :   76 (   1 ~  ;   1  |;  38  &)
%                                         (   0 <=>;  36 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    7 (   0 propositional; 1-3 arity)
%            Number of functors    :    9 (   5 constant; 0-2 arity)
%            Number of variables   :  101 (   0 singleton; 100 !;   1 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Substitution axioms
input_formula(appear_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(A,C),appear(B,C)) )   )).

input_formula(appear_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(C,A),appear(C,B)) )   )).

input_formula(cardinality_at_time_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(A,C),cardinality_at_time(B,C)) )   )).

input_formula(cardinality_at_time_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(C,A),cardinality_at_time(C,B)) )   )).

input_formula(number_of_organizations_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(number_of_organizations(A,C),
number_of_organizations(B,C)) )   )).

input_formula(number_of_organizations_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(number_of_organizations(C,A),
number_of_organizations(C,B)) )   )).

input_formula(start_time_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(start_time(A),start_time(B)) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(greater_or_equal_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(A,C) )
     => greater_or_equal(B,C) )   )).

input_formula(greater_or_equal_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(C,A) )
     => greater_or_equal(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(selection_favors_substitution_1,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(A,C,D) )
     => selection_favors(B,C,D) )   )).

input_formula(selection_favors_substitution_2,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(C,A,D) )
     => selection_favors(C,B,D) )   )).

input_formula(selection_favors_substitution_3,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(C,D,A) )
     => selection_favors(C,D,B) )   )).

input_formula(subpopulation_substitution_1,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & subpopulation(A,C,D) )
     => subpopulation(B,C,D) )   )).

input_formula(subpopulation_substitution_2,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & subpopulation(C,A,D) )
     => subpopulation(C,B,D) )   )).

input_formula(subpopulation_substitution_3,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & subpopulation(C,D,A) )
     => subpopulation(C,D,B) )   )).

%----Problem axioms
%----MP2. Selection favors organizational sets with members to set without
%----members.
input_formula(mp2_favour_members,axiom,(
    ! [E,S1,S2,T] : 
      ( ( environment(E)
        & subpopulation(S1,E,T)
        & subpopulation(S2,E,T)
        & greater(cardinality_at_time(S1,T),zero)
        & equal(cardinality_at_time(S2,T),zero) )
     => selection_favors(S1,S2,T) )   )).

%----MP. Object x is not present in the environment before it appears in
%----the environment.
input_formula(mp_not_present_before_appearance,axiom,(
    ! [E,X,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater(appear(X,E),T) )
     => equal(cardinality_at_time(X,T),zero) )   )).

%----MP. If the sum of organizations in an environment is positive, then
%----some of the constituent organizational groups must have members.
input_formula(mp_positive_sum_means_members,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & greater(number_of_organizations(E,T),zero) )
     => ? [X] : 
          ( subpopulation(X,E,T)
          & greater(cardinality_at_time(X,T),zero) ) )   )).

%----MP. If the number of elements in x is zero, then it is not positive.
input_formula(mp_zero_is_not_positive,axiom,(
    ! [X,T] : 
      ( equal(cardinality_at_time(X,t),zero)
     => ~ greater(cardinality_at_time(X,T),zero) )   )).

%----MP. If the number of organizations is positive in an environment at
%----time-point t, then t occurs during the environment sustains.
input_formula(mp_positive_and_sustains,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & greater(number_of_organizations(E,T),zero) )
     => in_environment(E,T) )   )).

%----MP. The durations of environments are time-intervals.
input_formula(mp_durations_are_time_intervals,axiom,(
    ! [E,T1,T2,T] : 
      ( ( environment(E)
        & in_environment(E,T1)
        & in_environment(E,T2)
        & greater_or_equal(T2,T)
        & greater_or_equal(T,T1) )
     => in_environment(E,T) )   )).

%----MP. The opening time of the environment belongs to the environment's
%----duration.
input_formula(mp_opening_time_in_duration,axiom,(
    ! [E] : 
      ( environment(E)
     => in_environment(E,start_time(E)) )   )).

%----MP. FM cannot appear in an environment before it opens.
input_formula(mp_no_FM_before_opening,axiom,(
    ! [E] : 
      ( environment(E)
     => greater_or_equal(appear(first_movers,E),start_time(E)) )   )).

%----MP. First movers and efficient producers are subpopulations.
input_formula(mp_subpopulations,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T) )
     => ( subpopulation(first_movers,E,T)
        & subpopulation(efficient_producers,E,T) ) )   )).

%----MP. If FM appear in the environment, then some organizations appear in
%----the environment.
input_formula(mp_FM_means_organisations,axiom,(
    ! [E] : 
      ( ( environment(E)
        & in_environment(E,appear(first_movers,E)) )
     => in_environment(E,appear(an_organisation,E)) )   )).

%----A1. The environment has a positive carrying capacity
input_formula(a1,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater_or_equal(T,appear(an_organisation,E)) )
     => greater(number_of_organizations(E,T),zero) )   )).

%----A9. The population contains only first movers and efficient
%----producers.
input_formula(a9,hypothesis,(
    ! [E,X,T] : 
      ( ( environment(E)
        & subpopulation(X,E,T)
        & greater(cardinality_at_time(X,T),zero) )
     => ( equal(X,efficient_producers)
        | equal(X,first_movers) ) )   )).

%----L13. First movers are the first organizations that appear in the
%----environment.
input_formula(l13,hypothesis,(
    ! [E] : 
      ( ( environment(E)
        & in_environment(E,appear(an_organisation,E)) )
     => equal(appear(an_organisation,E),appear(first_movers,E)) )   )).

%----GOAL:T2. Selection favors first movers above efficient producers
%----between the appearence of first movers and the appearence of efficient
%----producers.
input_formula(prove_t2,conjecture,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater_or_equal(T,appear(first_movers,E))
        & greater(appear(efficient_producers,E),T) )
     => selection_favors(first_movers,efficient_producers,T) )   )).
%--------------------------------------------------------------------------
