%--------------------------------------------------------------------------
% File     : MGT042+1 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Conditions for a lower hazard of mortality
% Version  : [Han98] axioms.
% English  : When an organization lacks immunity, increased collective
%            knowledge and superior external ties lower its hazard of
%            mortality when internal friction does not increase.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [Kam00]
% Names    : LEMMA 1 [Han98]

% Status   : theorem
% Rating   : 0.78 v2.7.0, 0.67 v2.6.0, 0.83 v2.4.0
% Syntax   : Number of formulae    :   36 (   1 unit)
%            Number of atoms       :  117 (  52 equality)
%            Maximal formula depth :    7 (   3 average)
%            Number of connectives :   86 (   5 ~  ;   4  |;  34  &)
%                                         (   3 <=>;  40 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    7 (   0 propositional; 1-2 arity)
%            Number of functors    :    6 (   0 constant; 2-2 arity)
%            Number of variables   :   99 (   0 singleton;  99 !;   0 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : The original text uses mnemonic names:
%            Original:    C/F/P:  Arity:    New name:
%            zero-symbol  c       0         zero
%            eta-symbol   c       0         eta
%            sigma-symbol c       0         sigma
%            tau-symbol   c       0         tau
%            very_low     c       0         very_low
%            low          c       0         low
%            mod1         c       0         mod1
%            mod2         c       0         mod2
%            high         c       0         high
%            A            f       2         age  
%            H            f       2         hazard_of_mortality  
%            C            f       2         capability  
%            P            f       2         position  
%            K            f       2         stock_of_knowledge  
%            T            f       2         external_ties  
%            F            f       2         internal_friction  
%            O            p       1         organization  
%            EN           p       1         has_endowment  
%            IM           p       2         has_immunity  
%            DS           p       3         dissimilar  
%            AL           p       2         is_aligned  
%            PA           p       2         positional_advantage  
%            FG           p       1         fragile_position  
%            RB           p       1         robust_position  
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%----Include inequality axioms
include('Axioms/MGT001+0.ax').
include('Axioms/MGT001+0.eq').
%--------------------------------------------------------------------------
input_formula(capability_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(capability(A,C),capability(B,C)) )   )).

input_formula(capability_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(capability(C,A),capability(C,B)) )   )).

input_formula(external_ties_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(external_ties(A,C),external_ties(B,C)) )   )).

input_formula(external_ties_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(external_ties(C,A),external_ties(C,B)) )   )).

input_formula(hazard_of_mortality_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C)) )   )).

input_formula(hazard_of_mortality_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B)) )   )).

input_formula(internal_friction_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(internal_friction(A,C),internal_friction(B,C)) )   )).

input_formula(internal_friction_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(internal_friction(C,A),internal_friction(C,B)) )   )).

input_formula(position_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(position(A,C),position(B,C)) )   )).

input_formula(position_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(position(C,A),position(C,B)) )   )).

input_formula(stock_of_knowledge_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(stock_of_knowledge(A,C),stock_of_knowledge(B,C)) )   )).

input_formula(stock_of_knowledge_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(stock_of_knowledge(C,A),stock_of_knowledge(C,B)) )   )).

input_formula(has_immunity_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(A,C) )
     => has_immunity(B,C) )   )).

input_formula(has_immunity_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(C,A) )
     => has_immunity(C,B) )   )).

input_formula(organization_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & organization(A) )
     => organization(B) )   )).

%----Problem Axioms
%----When an organization lacks immunity, superior capability and
%----position imply a lower hazard of mortality.
input_formula(assumption_4,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & ~ has_immunity(X,T0)
        & ~ has_immunity(X,T) )
     => ( ( ( greater(capability(X,T),capability(X,T0))
            & greater_or_equal(position(X,T),position(X,T0)) )
         => smaller(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) )
        & ( ( greater_or_equal(capability(X,T),capability(X,T0))
            & greater(position(X,T),position(X,T0)) )
         => smaller(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) )
        & ( ( equal(capability(X,T),capability(X,T0))
            & equal(position(X,T),position(X,T0)) )
         => equal(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) ) ) )   )).

%----Increased knowledge elevates an organization's capability; and
%----increased accumulation of organizational internal frictions
%----diminishes its capability.
input_formula(assumption_5,axiom,(
    ! [X,T0,T] : 
      ( organization(X)
     => ( ( ( greater(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & smaller_or_equal(internal_friction(X,T),internal_friction(X,T0)) )
         => greater(capability(X,T),capability(X,T0)) )
        & ( ( smaller_or_equal(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & greater(internal_friction(X,T),internal_friction(X,T0)) )
         => smaller(capability(X,T),capability(X,T0)) )
        & ( ( equal(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & equal(internal_friction(X,T),internal_friction(X,T0)) )
         => equal(capability(X,T),capability(X,T0)) ) ) )   )).

%----Improved ties with external actors enhance an organization's position.
input_formula(assumption_6,axiom,(
    ! [X,T0,T] : 
      ( organization(X)
     => ( ( greater(external_ties(X,T),external_ties(X,T0))
         => greater(position(X,T),position(X,T0)) )
        & ( equal(external_ties(X,T),external_ties(X,T0))
         => equal(position(X,T),position(X,T0)) ) ) )   )).

%----Problem theorems
%----When an organization lacks immunity, increased collective
%----knowledge and superior external ties lower its hazard of
%----mortality when internal friction does not increase.
%----From A4, A5, and A6 (text says A1-6; also needs D<, D>=, D<=).
input_formula(lemma_1,conjecture,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & ~ has_immunity(X,T0)
        & ~ has_immunity(X,T) )
     => ( ( ( greater(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & smaller_or_equal(internal_friction(X,T),internal_friction(X,T0))
            & greater_or_equal(external_ties(X,T),external_ties(X,T0)) )
         => smaller(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) )
        & ( ( greater_or_equal(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & smaller_or_equal(internal_friction(X,T),internal_friction(X,T0))
            & greater(external_ties(X,T),external_ties(X,T0)) )
         => smaller(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) ) ) )   )).
%--------------------------------------------------------------------------
