%--------------------------------------------------------------------------
% File     : MGT044+1 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Capability increases monotonically with age
% Version  : [Han98] axioms.
% English  : An organization's capability increases monotonically with its age.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [Kam00]
% Names    : LEMMA 3 [Han98]

% Status   : theorem
% Rating   : 0.11 v2.7.0, 0.17 v2.5.0, 0.00 v2.4.0
% Syntax   : Number of formulae    :   30 (   1 unit)
%            Number of atoms       :   83 (  38 equality)
%            Maximal formula depth :    7 (   3 average)
%            Number of connectives :   54 (   1 ~  ;   4  |;  19  &)
%                                         (   3 <=>;  27 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    6 (   0 propositional; 1-2 arity)
%            Number of functors    :    4 (   0 constant; 2-2 arity)
%            Number of variables   :   81 (   0 singleton;  81 !;   0 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%----Include inequality axioms
include('Axioms/MGT001+0.ax').
include('Axioms/MGT001+0.eq').
%--------------------------------------------------------------------------
input_formula(age_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(age(A,C),age(B,C)) )   )).
      
input_formula(age_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(age(C,A),age(C,B)) )   )).
      
input_formula(capability_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(capability(A,C),capability(B,C)) )   )).

input_formula(capability_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(capability(C,A),capability(C,B)) )   )).

input_formula(internal_friction_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(internal_friction(A,C),internal_friction(B,C)) )   )).

input_formula(internal_friction_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(internal_friction(C,A),internal_friction(C,B)) )   )).

input_formula(stock_of_knowledge_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(stock_of_knowledge(A,C),stock_of_knowledge(B,C)) )   )).

input_formula(stock_of_knowledge_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(stock_of_knowledge(C,A),stock_of_knowledge(C,B)) )   )).

input_formula(organization_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & organization(A) )
     => organization(B) )   )).

%----Problem Axioms
%----Increased knowledge elevates an organization's capability; and
%----increased accumulation of organizational internal frictions
%----diminishes its capability.
input_formula(assumption_5,axiom,(
    ! [X,T0,T] : 
      ( organization(X)
     => ( ( ( greater(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & smaller_or_equal(internal_friction(X,T),internal_friction(X,T0)) )
         => greater(capability(X,T),capability(X,T0)) )
        & ( ( smaller_or_equal(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & greater(internal_friction(X,T),internal_friction(X,T0)) )
         => smaller(capability(X,T),capability(X,T0)) )
        & ( ( equal(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & equal(internal_friction(X,T),internal_friction(X,T0)) )
         => equal(capability(X,T),capability(X,T0)) ) ) )   )).

%----Case: liability of Newness (Ass. 7-9).
%----
%----An organization's stock of knowledge increases monotonically with 
%----its age.
input_formula(assumption_7,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & greater(age(X,T),age(X,T0)) )
     => greater(stock_of_knowledge(X,T),stock_of_knowledge(X,T0)) )   )).

%----The quality of an organization's internal friction does not vary
%----with its age.
input_formula(assumption_9,axiom,(
    ! [X,T0,T] : 
      ( organization(X)
     => equal(internal_friction(X,T),internal_friction(X,T0)) )   )).

%----Problem theorems
%----Case B: liability of newness.
%----
%----An organization's capability increases monotonically with its age. 
%----From A5, A7, and A9 (text says A5,7-9; also needs D<=).
input_formula(lemma_3,conjecture,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & greater(age(X,T),age(X,T0)) )
     => greater(capability(X,T),capability(X,T0)) )   )).
%--------------------------------------------------------------------------
