%--------------------------------------------------------------------------
% File     : MGT045+1 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Structural position increases monotonically with age
% Version  : [Han98] axioms.
% English  : An organization's structural position increases monotonically
%            with its age.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [Kam00]
% Names    : LEMMA 4 [Han98]

% Status   : theorem
% Rating   : 0.00 v2.4.0
% Syntax   : Number of formulae    :   27 (   1 unit)
%            Number of atoms       :   72 (  32 equality)
%            Maximal formula depth :    5 (   3 average)
%            Number of connectives :   46 (   1 ~  ;   4  |;  15  &)
%                                         (   3 <=>;  23 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    6 (   0 propositional; 1-2 arity)
%            Number of functors    :    3 (   0 constant; 2-2 arity)
%            Number of variables   :   72 (   0 singleton;  72 !;   0 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%----Include inequality axioms
include('Axioms/MGT001+0.ax').
include('Axioms/MGT001+0.eq').
%--------------------------------------------------------------------------
input_formula(age_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(age(A,C),age(B,C)) )   )).
    
input_formula(age_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(age(C,A),age(C,B)) )   )).

input_formula(external_ties_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(external_ties(A,C),external_ties(B,C)) )   )).

input_formula(external_ties_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(external_ties(C,A),external_ties(C,B)) )   )).

input_formula(position_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(position(A,C),position(B,C)) )   )).

input_formula(position_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(position(C,A),position(C,B)) )   )).

input_formula(organization_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & organization(A) )
     => organization(B) )   )).

%----Problem Axioms
%----Improved ties with external actors enhance an organization's position.
input_formula(assumption_6,axiom,(
    ! [X,T0,T] : 
      ( organization(X)
     => ( ( greater(external_ties(X,T),external_ties(X,T0))
         => greater(position(X,T),position(X,T0)) )
        & ( equal(external_ties(X,T),external_ties(X,T0))
         => equal(position(X,T),position(X,T0)) ) ) )   )).

%----The quality of an organization's external ties increases
%----monotonically with its age.
input_formula(assumption_8,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & greater(age(X,T),age(X,T0)) )
     => greater(external_ties(X,T),external_ties(X,T0)) )   )).

%----Problem theorems
%----An organization's structural position increases monotonically
%----with its age.  
%----From A6 and A8 (no inequalities needed).
input_formula(lemma_4,conjecture,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & greater(age(X,T),age(X,T0)) )
     => greater(position(X,T),position(X,T0)) )   )).
%--------------------------------------------------------------------------
