%--------------------------------------------------------------------------
% File     : MGT047+1 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Conditions for changing hazard of mortality
% Version  : [Han98] axioms.
% English  : An endowed organization's hazard of mortality is constant during 
%            its period of immunity, jumps when its immunity ends, and 
%            decreases with further aging but remains above the level during 
%            the immunity period.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [Kam00]
% Names    : THEOREM 2 [Han98]

% Status   : theorem
% Rating   : 0.44 v2.7.0, 0.50 v2.4.0
% Syntax   : Number of formulae    :   45 (   1 unit)
%            Number of atoms       :  144 (  60 equality)
%            Maximal formula depth :    8 (   3 average)
%            Number of connectives :  104 (   5 ~  ;   4  |;  43  &)
%                                         (   4 <=>;  48 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    8 (   0 propositional; 1-2 arity)
%            Number of functors    :    8 (   1 constant; 0-2 arity)
%            Number of variables   :  126 (   0 singleton; 126 !;   0 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%----Include inequality axioms
include('Axioms/MGT001+0.ax').
include('Axioms/MGT001+0.eq').
%--------------------------------------------------------------------------
input_formula(age_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(age(A,C),age(B,C)) )   )).
      
input_formula(age_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(age(C,A),age(C,B)) )   )).

input_formula(capability_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(capability(A,C),capability(B,C)) )   )).

input_formula(capability_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(capability(C,A),capability(C,B)) )   )).

input_formula(external_ties_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(external_ties(A,C),external_ties(B,C)) )   )).

input_formula(external_ties_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(external_ties(C,A),external_ties(C,B)) )   )).

input_formula(hazard_of_mortality_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C)) )   )).

input_formula(hazard_of_mortality_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B)) )   )).

input_formula(internal_friction_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(internal_friction(A,C),internal_friction(B,C)) )   )).

input_formula(internal_friction_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(internal_friction(C,A),internal_friction(C,B)) )   )).

input_formula(position_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(position(A,C),position(B,C)) )   )).

input_formula(position_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(position(C,A),position(C,B)) )   )).

input_formula(stock_of_knowledge_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(stock_of_knowledge(A,C),stock_of_knowledge(B,C)) )   )).

input_formula(stock_of_knowledge_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(stock_of_knowledge(C,A),stock_of_knowledge(C,B)) )   )).

input_formula(has_endowment_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & has_endowment(A) )
     => has_endowment(B) )   )).

input_formula(has_immunity_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(A,C) )
     => has_immunity(B,C) )   )).

input_formula(has_immunity_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(C,A) )
     => has_immunity(C,B) )   )).

input_formula(organization_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & organization(A) )
     => organization(B) )   )).

%----Problem Axioms
%----An endowment provides an immunity that lasts until an
%----organization's age exceeds `eta'.
input_formula(definition_1,axiom,(
    ! [X] : 
      ( has_endowment(X)
    <=> ! [T] : 
          ( organization(X)
          & ( smaller_or_equal(age(X,T),eta)
           => has_immunity(X,T) )
          & ( greater(age(X,T),eta)
           => ~ has_immunity(X,T) ) ) )   )).

%----An organization's hazard of mortality is constant during periods
%----in which it has immunity.
input_formula(assumption_2,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & has_immunity(X,T0)
        & has_immunity(X,T) )
     => equal(hazard_of_mortality(X,T0),hazard_of_mortality(X,T)) )   )).

%----An organization's hazard of mortality is lower during periods in
%----which it has immunity than in periods in which it does not.
input_formula(assumption_3,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & has_immunity(X,T0)
        & ~ has_immunity(X,T) )
     => greater(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) )   )).

%----When an organization lacks immunity, superior capability and
%----position imply a lower hazard of mortality.
input_formula(assumption_4,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & ~ has_immunity(X,T0)
        & ~ has_immunity(X,T) )
     => ( ( ( greater(capability(X,T),capability(X,T0))
            & greater_or_equal(position(X,T),position(X,T0)) )
         => smaller(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) )
        & ( ( greater_or_equal(capability(X,T),capability(X,T0))
            & greater(position(X,T),position(X,T0)) )
         => smaller(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) )
        & ( ( equal(capability(X,T),capability(X,T0))
            & equal(position(X,T),position(X,T0)) )
         => equal(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) ) ) )   )).

%----Increased knowledge elevates an organization's capability; and
%----increased accumulation of organizational internal frictions
%----diminishes its capability.
input_formula(assumption_5,axiom,(
    ! [X,T0,T] : 
      ( organization(X)
     => ( ( ( greater(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & smaller_or_equal(internal_friction(X,T),internal_friction(X,T0)) )
         => greater(capability(X,T),capability(X,T0)) )
        & ( ( smaller_or_equal(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & greater(internal_friction(X,T),internal_friction(X,T0)) )
         => smaller(capability(X,T),capability(X,T0)) )
        & ( ( equal(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & equal(internal_friction(X,T),internal_friction(X,T0)) )
         => equal(capability(X,T),capability(X,T0)) ) ) )   )).

%----Improved ties with external actors enhance an organization's position.
input_formula(assumption_6,axiom,(
    ! [X,T0,T] : 
      ( organization(X)
     => ( ( greater(external_ties(X,T),external_ties(X,T0))
         => greater(position(X,T),position(X,T0)) )
        & ( equal(external_ties(X,T),external_ties(X,T0))
         => equal(position(X,T),position(X,T0)) ) ) )   )).

%----Case: liability of Newness (Ass. 7-9).
%----
%----An organization's stock of knowledge increases monotonically with 
%----its age.
input_formula(assumption_7,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & greater(age(X,T),age(X,T0)) )
     => greater(stock_of_knowledge(X,T),stock_of_knowledge(X,T0)) )   )).

%----The quality of an organization's external ties increases
%----monotonically with its age.
input_formula(assumption_8,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & greater(age(X,T),age(X,T0)) )
     => greater(external_ties(X,T),external_ties(X,T0)) )   )).

%----The quality of an organization's internal friction does not vary
%----with its age.
input_formula(assumption_9,axiom,(
    ! [X,T0,T] : 
      ( organization(X)
     => equal(internal_friction(X,T),internal_friction(X,T0)) )   )).

%----Problem theorems
%----The liability-of-adolescence theorem (Bruederl and Schuessler
%----1990; Fichman and Levinthal 1991):  an endowed organization's
%----hazard of mortality is constant during its period of immunity,
%----jumps when its immunity ends, and decreases with further aging
%----but remains above the level during the immunity period.
%----From D1 and A2-9 (text says D1, A1-4, L1-2; also needs D<, D<=, D>=, 
%----MP>str, MP>com).
input_formula(theorem_2,conjecture,(
    ! [X,T0,T1,T2,T3] : 
      ( ( organization(X)
        & has_endowment(X)
        & smaller_or_equal(age(X,T0),age(X,T1))
        & smaller_or_equal(age(X,T1),eta)
        & greater(age(X,T2),eta)
        & greater(age(X,T3),age(X,T2)) )
     => ( greater(hazard_of_mortality(X,T2),hazard_of_mortality(X,T3))
        & greater(hazard_of_mortality(X,T3),hazard_of_mortality(X,T1))
        & equal(hazard_of_mortality(X,T1),hazard_of_mortality(X,T0)) ) )   )).
%--------------------------------------------------------------------------
