%--------------------------------------------------------------------------
% File     : MGT050+1 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Unendowed organization's hazard of mortality increases with age
% Version  : [Han98] axioms.
% English  : An unendowed organization's hazard of mortality increases with 
%            its age.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [Kam00]
% Names    : THEOREM 3 [Han98]

% Status   : theorem
% Rating   : 0.22 v2.7.0, 0.17 v2.6.0, 0.33 v2.5.0, 0.17 v2.4.0
% Syntax   : Number of formulae    :   43 (   1 unit)
%            Number of atoms       :  127 (  59 equality)
%            Maximal formula depth :    7 (   3 average)
%            Number of connectives :   90 (   6 ~  ;   4  |;  32  &)
%                                         (   3 <=>;  45 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    8 (   0 propositional; 1-2 arity)
%            Number of functors    :    7 (   0 constant; 2-2 arity)
%            Number of variables   :  118 (   0 singleton; 118 !;   0 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%----Include inequality axioms
include('Axioms/MGT001+0.ax').
include('Axioms/MGT001+0.eq').
%--------------------------------------------------------------------------
input_formula(age_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(age(A,C),age(B,C)) )   )).
     
input_formula(age_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(age(C,A),age(C,B)) )   )).

input_formula(capability_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(capability(A,C),capability(B,C)) )   )).

input_formula(capability_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(capability(C,A),capability(C,B)) )   )).

input_formula(external_ties_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(external_ties(A,C),external_ties(B,C)) )   )).

input_formula(external_ties_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(external_ties(C,A),external_ties(C,B)) )   )).

input_formula(hazard_of_mortality_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C)) )   )).

input_formula(hazard_of_mortality_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B)) )   )).

input_formula(internal_friction_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(internal_friction(A,C),internal_friction(B,C)) )   )).

input_formula(internal_friction_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(internal_friction(C,A),internal_friction(C,B)) )   )).

input_formula(position_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(position(A,C),position(B,C)) )   )).

input_formula(position_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(position(C,A),position(C,B)) )   )).

input_formula(stock_of_knowledge_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(stock_of_knowledge(A,C),stock_of_knowledge(B,C)) )   )).

input_formula(stock_of_knowledge_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(stock_of_knowledge(C,A),stock_of_knowledge(C,B)) )   )).

input_formula(has_endowment_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & has_endowment(A) )
     => has_endowment(B) )   )).

input_formula(has_immunity_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(A,C) )
     => has_immunity(B,C) )   )).

input_formula(has_immunity_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(C,A) )
     => has_immunity(C,B) )   )).

input_formula(organization_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & organization(A) )
     => organization(B) )   )).

%----Problem Axioms
%----An unendowed organization never possesses immunity.
input_formula(assumption_1,axiom,(
    ! [X,T] : 
      ( ( organization(X)
        & ~ has_endowment(X) )
     => ~ has_immunity(X,T) )   )).

%----When an organization lacks immunity, superior capability and
%----position imply a lower hazard of mortality.
input_formula(assumption_4,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & ~ has_immunity(X,T0)
        & ~ has_immunity(X,T) )
     => ( ( ( greater(capability(X,T),capability(X,T0))
            & greater_or_equal(position(X,T),position(X,T0)) )
         => smaller(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) )
        & ( ( greater_or_equal(capability(X,T),capability(X,T0))
            & greater(position(X,T),position(X,T0)) )
         => smaller(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) )
        & ( ( equal(capability(X,T),capability(X,T0))
            & equal(position(X,T),position(X,T0)) )
         => equal(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) ) ) )   )).

%----Increased knowledge elevates an organization's capability; and
%----increased accumulation of organizational internal frictions
%----diminishes its capability.
input_formula(assumption_5,axiom,(
    ! [X,T0,T] : 
      ( organization(X)
     => ( ( ( greater(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & smaller_or_equal(internal_friction(X,T),internal_friction(X,T0)) )
         => greater(capability(X,T),capability(X,T0)) )
        & ( ( smaller_or_equal(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & greater(internal_friction(X,T),internal_friction(X,T0)) )
         => smaller(capability(X,T),capability(X,T0)) )
        & ( ( equal(stock_of_knowledge(X,T),stock_of_knowledge(X,T0))
            & equal(internal_friction(X,T),internal_friction(X,T0)) )
         => equal(capability(X,T),capability(X,T0)) ) ) )   )).

%----Improved ties with external actors enhance an organization's position.
input_formula(assumption_6,axiom,(
    ! [X,T0,T] : 
      ( organization(X)
     => ( ( greater(external_ties(X,T),external_ties(X,T0))
         => greater(position(X,T),position(X,T0)) )
        & ( equal(external_ties(X,T),external_ties(X,T0))
         => equal(position(X,T),position(X,T0)) ) ) )   )).

%----Case: liability of senescence (Ass. 10-12 replacing A7-9)!
%----
%----An organization's stock of knowledge does not vary with its age
%----(contra assumption 7).
input_formula(assumption_10,axiom,(
    ! [X,T0,T] : 
      ( organization(X)
     => equal(stock_of_knowledge(X,T),stock_of_knowledge(X,T0)) )   )).

%----The quality of an organization's external ties does not vary with
%----its age (contra assumption 8).
input_formula(assumption_11,axiom,(
    ! [X,T0,T] : 
      ( organization(X)
     => equal(external_ties(X,T),external_ties(X,T0)) )   )).

%----The quality of an organization's internal friction increases
%----monotonically with its age (contra assumption 9).
input_formula(assumption_12,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & greater(age(X,T),age(X,T0)) )
     => greater(internal_friction(X,T),internal_friction(X,T0)) )   )).

%----Problem theorems
%----The senescence theorem for unendowed organizations (Barron et
%----al. 1994): an unendowed organization's hazard of mortality
%----increases with its age.
%----From A1, A4-6, and A10-12 (text says D1, A1-4, L5-6; also needs D<, 
%----D<=, D>=).
input_formula(theorem_3,conjecture,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & ~ has_endowment(X)
        & greater(age(X,T),age(X,T0)) )
     => greater(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) )   )).
%--------------------------------------------------------------------------
