%--------------------------------------------------------------------------
% File     : MGT054-1 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Hazard of mortality increases in a drifting environment
% Version  : [Han98] axioms.
% English  : An unendowed organization's hazard of mortality increases with 
%            age in a drifting environment.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [TPTP]
% Names    : 

% Status   : unsatisfiable
% Rating   : 0.09 v2.7.0, 0.08 v2.6.0, 0.00 v2.5.0, 0.11 v2.4.0
% Syntax   : Number of clauses    :   58 (  11 non-Horn;   8 unit;  44 RR)
%            Number of literals   :  153 (  44 equality)
%            Maximal clause size  :    5 (   2 average)
%            Number of predicates :   10 (   0 propositional; 1-3 arity)
%            Number of functors   :    9 (   6 constant; 0-2 arity)
%            Number of variables  :  139 (   5 singleton)
%            Maximal term depth   :    2 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%          : Created with tptp2X -f tptp -t clausify:otter MGT054+1.p 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001-0.ax').
%----Include inequality axioms
include('Axioms/MGT001-0.ax').
include('Axioms/MGT001-0.eq').
%--------------------------------------------------------------------------
input_clause(age_substitution_1_23,axiom,
    [--equal(A,B),
     ++equal(age(A,C),age(B,C))]).

input_clause(age_substitution_2_24,axiom,
    [--equal(A,B),
     ++equal(age(C,A),age(C,B))]).

input_clause(capability_substitution_1_25,axiom,
    [--equal(A,B),
     ++equal(capability(A,C),capability(B,C))]).

input_clause(capability_substitution_2_26,axiom,
    [--equal(A,B),
     ++equal(capability(C,A),capability(C,B))]).

input_clause(hazard_of_mortality_substitution_1_27,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C))]).

input_clause(hazard_of_mortality_substitution_2_28,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B))]).

input_clause(dissimilar_substitution_1_29,axiom,
    [--equal(A,B),
     --dissimilar(A,C,D),
     ++dissimilar(B,C,D)]).

input_clause(dissimilar_substitution_2_30,axiom,
    [--equal(A,B),
     --dissimilar(C,A,D),
     ++dissimilar(C,B,D)]).

input_clause(dissimilar_substitution_3_31,axiom,
    [--equal(A,B),
     --dissimilar(C,D,A),
     ++dissimilar(C,D,B)]).

input_clause(has_endowment_substitution_1_32,axiom,
    [--equal(A,B),
     --has_endowment(A),
     ++has_endowment(B)]).

input_clause(has_immunity_substitution_1_33,axiom,
    [--equal(A,B),
     --has_immunity(A,C),
     ++has_immunity(B,C)]).

input_clause(has_immunity_substitution_2_34,axiom,
    [--equal(A,B),
     --has_immunity(C,A),
     ++has_immunity(C,B)]).

input_clause(is_aligned_substitution_1_35,axiom,
    [--equal(A,B),
     --is_aligned(A,C),
     ++is_aligned(B,C)]).

input_clause(is_aligned_substitution_2_36,axiom,
    [--equal(A,B),
     --is_aligned(C,A),
     ++is_aligned(C,B)]).

input_clause(organization_substitution_1_37,axiom,
    [--equal(A,B),
     --organization(A),
     ++organization(B)]).

input_clause(assumption_1_38,axiom,
    [--organization(A),
     ++has_endowment(A),
     --has_immunity(A,B)]).

input_clause(assumption_3_39,axiom,
    [--organization(A),
     --has_immunity(A,B),
     ++has_immunity(A,C),
     ++greater(hazard_of_mortality(A,C),hazard_of_mortality(A,B))]).

input_clause(definition_2_40,axiom,
    [--dissimilar(A,B,C),
     ++organization(A)]).

input_clause(definition_2_41,axiom,
    [--dissimilar(A,B,C),
     ++is_aligned(A,B),
     ++is_aligned(A,C)]).

input_clause(definition_2_42,axiom,
    [--dissimilar(A,B,C),
     --is_aligned(A,B),
     --is_aligned(A,C)]).

input_clause(definition_2_43,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,B),
     ++dissimilar(A,B,C)]).

input_clause(definition_2_44,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,C),
     ++dissimilar(A,B,C)]).

input_clause(definition_2_45,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,C),
     ++dissimilar(A,C,B)]).

input_clause(definition_2_46,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,B),
     ++dissimilar(A,C,B)]).

input_clause(assumption_13_47,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     ++is_aligned(A,B)]).

input_clause(assumption_14_48,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,C),
     ++greater(capability(A,B),capability(A,C))]).

input_clause(assumption_15_49,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     --greater(age(A,C),sigma),
     ++dissimilar(A,B,C)]).

input_clause(assumption_15_50,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     --dissimilar(A,B,C),
     ++greater(age(A,C),sigma)]).

input_clause(assumption_16_51,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++has_immunity(A,C),
     --greater(capability(A,C),capability(A,B)),
     ++greater(hazard_of_mortality(A,B),hazard_of_mortality(A,C))]).

input_clause(theorem_5_52,conjecture,
    [++organization(sk1)]).

input_clause(theorem_5_53,conjecture,
    [--has_endowment(sk1)]).

input_clause(theorem_5_54,conjecture,
    [++equal(age(sk1,sk2),zero)]).

input_clause(theorem_5_55,conjecture,
    [++smaller_or_equal(age(sk1,sk3),sigma)]).

input_clause(theorem_5_56,conjecture,
    [++greater(age(sk1,sk4),sigma)]).

input_clause(theorem_5_57,conjecture,
    [++greater(sigma,zero)]).

input_clause(theorem_5_58,conjecture,
    [--greater(hazard_of_mortality(sk1,sk4),hazard_of_mortality(sk1,sk3))]).
%--------------------------------------------------------------------------
