%--------------------------------------------------------------------------
% File     : MGT055-1 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Conditions for a constant then jumping hazard of mortality 1
% Version  : [Han98] axioms.
% English  : When (`eta' < `sigma') in a drifting environment, an endowed
%            organization's hazard of mortality remains constant until age
%            reaches `eta', then jumps to a higher level, then jumps again at
%            age `sigma'.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [TPTP]
% Names    : 

% Status   : unsatisfiable
% Rating   : 0.36 v2.7.0, 0.33 v2.6.0, 0.44 v2.5.0, 0.56 v2.4.0
% Syntax   : Number of clauses    :   68 (  15 non-Horn;  10 unit;  54 RR)
%            Number of literals   :  183 (  46 equality)
%            Maximal clause size  :    5 (   2 average)
%            Number of predicates :   10 (   0 propositional; 1-3 arity)
%            Number of functors   :   12 (   8 constant; 0-2 arity)
%            Number of variables  :  149 (   4 singleton)
%            Maximal term depth   :    3 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%          : Created with tptp2X -f tptp -t clausify:otter MGT055+1.p 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001-0.ax').
%----Include inequality axioms
include('Axioms/MGT001-0.ax').
include('Axioms/MGT001-0.eq').
%--------------------------------------------------------------------------
input_clause(age_substitution_1_23,axiom,
    [--equal(A,B),
     ++equal(age(A,C),age(B,C))]).

input_clause(age_substitution_2_24,axiom,
    [--equal(A,B),
     ++equal(age(C,A),age(C,B))]).

input_clause(capability_substitution_1_25,axiom,
    [--equal(A,B),
     ++equal(capability(A,C),capability(B,C))]).

input_clause(capability_substitution_2_26,axiom,
    [--equal(A,B),
     ++equal(capability(C,A),capability(C,B))]).

input_clause(hazard_of_mortality_substitution_1_27,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C))]).

input_clause(hazard_of_mortality_substitution_2_28,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B))]).

input_clause(dissimilar_substitution_1_29,axiom,
    [--equal(A,B),
     --dissimilar(A,C,D),
     ++dissimilar(B,C,D)]).

input_clause(dissimilar_substitution_2_30,axiom,
    [--equal(A,B),
     --dissimilar(C,A,D),
     ++dissimilar(C,B,D)]).

input_clause(dissimilar_substitution_3_31,axiom,
    [--equal(A,B),
     --dissimilar(C,D,A),
     ++dissimilar(C,D,B)]).

input_clause(has_endowment_substitution_1_32,axiom,
    [--equal(A,B),
     --has_endowment(A),
     ++has_endowment(B)]).

input_clause(has_immunity_substitution_1_33,axiom,
    [--equal(A,B),
     --has_immunity(A,C),
     ++has_immunity(B,C)]).

input_clause(has_immunity_substitution_2_34,axiom,
    [--equal(A,B),
     --has_immunity(C,A),
     ++has_immunity(C,B)]).

input_clause(is_aligned_substitution_1_35,axiom,
    [--equal(A,B),
     --is_aligned(A,C),
     ++is_aligned(B,C)]).

input_clause(is_aligned_substitution_2_36,axiom,
    [--equal(A,B),
     --is_aligned(C,A),
     ++is_aligned(C,B)]).

input_clause(organization_substitution_1_37,axiom,
    [--equal(A,B),
     --organization(A),
     ++organization(B)]).

input_clause(definition_1_38,axiom,
    [--has_endowment(A),
     ++organization(A)]).

input_clause(definition_1_39,axiom,
    [--has_endowment(A),
     --smaller_or_equal(age(A,B),eta),
     ++has_immunity(A,B)]).

input_clause(definition_1_40,axiom,
    [--has_endowment(A),
     --greater(age(A,B),eta),
     --has_immunity(A,B)]).

input_clause(definition_1_41,axiom,
    [--organization(A),
     ++smaller_or_equal(age(A,sk1(A)),eta),
     ++greater(age(A,sk1(A)),eta),
     ++has_endowment(A)]).

input_clause(definition_1_42,axiom,
    [--organization(A),
     ++smaller_or_equal(age(A,sk1(A)),eta),
     ++has_immunity(A,sk1(A)),
     ++has_endowment(A)]).

input_clause(definition_1_43,axiom,
    [--organization(A),
     --has_immunity(A,sk1(A)),
     ++greater(age(A,sk1(A)),eta),
     ++has_endowment(A)]).

input_clause(definition_1_44,axiom,
    [--organization(A),
     --has_immunity(A,sk1(A)),
     ++has_immunity(A,sk1(A)),
     ++has_endowment(A)]).

input_clause(assumption_2_45,axiom,
    [--organization(A),
     --has_immunity(A,B),
     --has_immunity(A,C),
     ++equal(hazard_of_mortality(A,B),hazard_of_mortality(A,C))]).

input_clause(assumption_3_46,axiom,
    [--organization(A),
     --has_immunity(A,B),
     ++has_immunity(A,C),
     ++greater(hazard_of_mortality(A,C),hazard_of_mortality(A,B))]).

input_clause(definition_2_47,axiom,
    [--dissimilar(A,B,C),
     ++organization(A)]).

input_clause(definition_2_48,axiom,
    [--dissimilar(A,B,C),
     ++is_aligned(A,B),
     ++is_aligned(A,C)]).

input_clause(definition_2_49,axiom,
    [--dissimilar(A,B,C),
     --is_aligned(A,B),
     --is_aligned(A,C)]).

input_clause(definition_2_50,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,B),
     ++dissimilar(A,B,C)]).

input_clause(definition_2_51,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,C),
     ++dissimilar(A,B,C)]).

input_clause(definition_2_52,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,C),
     ++dissimilar(A,C,B)]).

input_clause(definition_2_53,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,B),
     ++dissimilar(A,C,B)]).

input_clause(assumption_13_54,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     ++is_aligned(A,B)]).

input_clause(assumption_14_55,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,C),
     ++greater(capability(A,B),capability(A,C))]).

input_clause(assumption_15_56,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     --greater(age(A,C),sigma),
     ++dissimilar(A,B,C)]).

input_clause(assumption_15_57,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     --dissimilar(A,B,C),
     ++greater(age(A,C),sigma)]).

input_clause(assumption_16_58,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++has_immunity(A,C),
     --greater(capability(A,C),capability(A,B)),
     ++greater(hazard_of_mortality(A,B),hazard_of_mortality(A,C))]).

input_clause(lemma_8_59,conjecture,
    [++organization(sk2)]).

input_clause(lemma_8_60,conjecture,
    [++has_endowment(sk2)]).

input_clause(lemma_8_61,conjecture,
    [++equal(age(sk2,sk3),zero)]).

input_clause(lemma_8_62,conjecture,
    [++smaller_or_equal(age(sk2,sk4),eta)]).

input_clause(lemma_8_63,conjecture,
    [++greater(age(sk2,sk5),eta)]).

input_clause(lemma_8_64,conjecture,
    [++smaller_or_equal(age(sk2,sk5),sigma)]).

input_clause(lemma_8_65,conjecture,
    [++greater(age(sk2,sk6),sigma)]).

input_clause(lemma_8_66,conjecture,
    [++greater(sigma,eta)]).

input_clause(lemma_8_67,conjecture,
    [++greater(eta,zero)]).

input_clause(lemma_8_68,conjecture,
    [--greater(hazard_of_mortality(sk2,sk6),hazard_of_mortality(sk2,sk5)),
     --greater(hazard_of_mortality(sk2,sk5),hazard_of_mortality(sk2,sk4)),
     --equal(hazard_of_mortality(sk2,sk4),hazard_of_mortality(sk2,sk3))]).
%--------------------------------------------------------------------------
