%--------------------------------------------------------------------------
% File     : MGT057+1 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Conditions for a constant then increasing hazard of mortality
% Version  : [Han98] axioms.
% English  : In a drifting environment, an endowed organization's hazard of 
%            mortality is constant during the period of immunity; beyond the 
%            period of immunity, the hazard rises with age.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [Kam00]
% Names    : THEOREM 6 [Han98]

% Status   : theorem
% Rating   : 0.11 v2.7.0, 0.17 v2.6.0, 0.33 v2.5.0, 0.00 v2.4.0
% Syntax   : Number of formulae    :   29 (   1 unit)
%            Number of atoms       :   88 (  32 equality)
%            Maximal formula depth :    8 (   4 average)
%            Number of connectives :   62 (   3 ~  ;   4  |;  27  &)
%                                         (   4 <=>;  24 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    8 (   0 propositional; 1-2 arity)
%            Number of functors    :    4 (   2 constant; 0-2 arity)
%            Number of variables   :   77 (   0 singleton;  77 !;   0 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%----Include inequality axioms
include('Axioms/MGT001+0.ax').
include('Axioms/MGT001+0.eq').
%--------------------------------------------------------------------------
input_formula(age_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(age(A,C),age(B,C)) )   )).
      
input_formula(age_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(age(C,A),age(C,B)) )   )).

input_formula(hazard_of_mortality_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C)) )   )).

input_formula(hazard_of_mortality_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B)) )   )).

input_formula(has_endowment_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & has_endowment(A) )
     => has_endowment(B) )   )).

input_formula(has_immunity_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(A,C) )
     => has_immunity(B,C) )   )).

input_formula(has_immunity_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(C,A) )
     => has_immunity(C,B) )   )).

input_formula(organization_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & organization(A) )
     => organization(B) )   )).

%----Problem Axioms
%----An endowment provides an immunity that lasts until an
%----organization's age exceeds `eta'.
input_formula(definition_1,axiom,(
    ! [X] : 
      ( has_endowment(X)
    <=> ! [T] : 
          ( organization(X)
          & ( smaller_or_equal(age(X,T),eta)
           => has_immunity(X,T) )
          & ( greater(age(X,T),eta)
           => ~ has_immunity(X,T) ) ) )   )).

%----An organization's hazard of mortality is constant during periods
%----in which it has immunity.
input_formula(assumption_2,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & has_immunity(X,T0)
        & has_immunity(X,T) )
     => equal(hazard_of_mortality(X,T0),hazard_of_mortality(X,T)) )   )).

%----An organization's hazard of mortality is lower during periods in
%----which it has immunity than in periods in which it does not.
input_formula(assumption_3,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & has_immunity(X,T0)
        & ~ has_immunity(X,T) )
     => greater(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) )   )).

%----Problem theorems
%----The obsolescence theorem for endowed organizations: In a drifting 
%----environment, an endowed organization's hazard of mortality is
%----constant during the period of immunity; beyond the period of
%----immunity, the hazard rises with age.
%----From D1, A2, A3 (text says from L8,9; also needs D<, D<=).
%----
%----Text has redundant quantification over T3.
input_formula(theorem_6,conjecture,(
    ! [X,T0,T1,T2] : 
      ( ( organization(X)
        & has_endowment(X)
        & equal(age(X,T0),zero)
        & smaller_or_equal(age(X,T1),eta)
        & greater(age(X,T2),eta)
        & greater(eta,zero) )
     => ( greater(hazard_of_mortality(X,T2),hazard_of_mortality(X,T1))
        & equal(hazard_of_mortality(X,T1),hazard_of_mortality(X,T0)) ) )   )).
%--------------------------------------------------------------------------
