%--------------------------------------------------------------------------
% File     : MGT057-1 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Conditions for a constant then increasing hazard of mortality
% Version  : [Han98] axioms.
% English  : In a drifting environment, an endowed organization's hazard of 
%            mortality is constant during the period of immunity; beyond the 
%            period of immunity, the hazard rises with age.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [TPTP]
% Names    : 

% Status   : unsatisfiable
% Rating   : 0.09 v2.7.0, 0.08 v2.6.0, 0.00 v2.5.0, 0.11 v2.4.0
% Syntax   : Number of clauses    :   46 (   8 non-Horn;   7 unit;  39 RR)
%            Number of literals   :  116 (  34 equality)
%            Maximal clause size  :    4 (   2 average)
%            Number of predicates :    8 (   0 propositional; 1-2 arity)
%            Number of functors   :    9 (   6 constant; 0-2 arity)
%            Number of variables  :   90 (   0 singleton)
%            Maximal term depth   :    3 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%          : Created with tptp2X -f tptp -t clausify:otter MGT057+1.p 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001-0.ax').
%----Include inequality axioms
include('Axioms/MGT001-0.ax').
include('Axioms/MGT001-0.eq').
%--------------------------------------------------------------------------
input_clause(age_substitution_1_23,axiom,
    [--equal(A,B),
     ++equal(age(A,C),age(B,C))]).

input_clause(age_substitution_2_24,axiom,
    [--equal(A,B),
     ++equal(age(C,A),age(C,B))]).

input_clause(hazard_of_mortality_substitution_1_25,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C))]).

input_clause(hazard_of_mortality_substitution_2_26,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B))]).

input_clause(has_endowment_substitution_1_27,axiom,
    [--equal(A,B),
     --has_endowment(A),
     ++has_endowment(B)]).

input_clause(has_immunity_substitution_1_28,axiom,
    [--equal(A,B),
     --has_immunity(A,C),
     ++has_immunity(B,C)]).

input_clause(has_immunity_substitution_2_29,axiom,
    [--equal(A,B),
     --has_immunity(C,A),
     ++has_immunity(C,B)]).

input_clause(organization_substitution_1_30,axiom,
    [--equal(A,B),
     --organization(A),
     ++organization(B)]).

input_clause(definition_1_31,axiom,
    [--has_endowment(A),
     ++organization(A)]).

input_clause(definition_1_32,axiom,
    [--has_endowment(A),
     --smaller_or_equal(age(A,B),eta),
     ++has_immunity(A,B)]).

input_clause(definition_1_33,axiom,
    [--has_endowment(A),
     --greater(age(A,B),eta),
     --has_immunity(A,B)]).

input_clause(definition_1_34,axiom,
    [--organization(A),
     ++smaller_or_equal(age(A,sk1(A)),eta),
     ++greater(age(A,sk1(A)),eta),
     ++has_endowment(A)]).

input_clause(definition_1_35,axiom,
    [--organization(A),
     ++smaller_or_equal(age(A,sk1(A)),eta),
     ++has_immunity(A,sk1(A)),
     ++has_endowment(A)]).

input_clause(definition_1_36,axiom,
    [--organization(A),
     --has_immunity(A,sk1(A)),
     ++greater(age(A,sk1(A)),eta),
     ++has_endowment(A)]).

input_clause(definition_1_37,axiom,
    [--organization(A),
     --has_immunity(A,sk1(A)),
     ++has_immunity(A,sk1(A)),
     ++has_endowment(A)]).

input_clause(assumption_2_38,axiom,
    [--organization(A),
     --has_immunity(A,B),
     --has_immunity(A,C),
     ++equal(hazard_of_mortality(A,B),hazard_of_mortality(A,C))]).

input_clause(assumption_3_39,axiom,
    [--organization(A),
     --has_immunity(A,B),
     ++has_immunity(A,C),
     ++greater(hazard_of_mortality(A,C),hazard_of_mortality(A,B))]).

input_clause(theorem_6_40,conjecture,
    [++organization(sk2)]).

input_clause(theorem_6_41,conjecture,
    [++has_endowment(sk2)]).

input_clause(theorem_6_42,conjecture,
    [++equal(age(sk2,sk3),zero)]).

input_clause(theorem_6_43,conjecture,
    [++smaller_or_equal(age(sk2,sk4),eta)]).

input_clause(theorem_6_44,conjecture,
    [++greater(age(sk2,sk5),eta)]).

input_clause(theorem_6_45,conjecture,
    [++greater(eta,zero)]).

input_clause(theorem_6_46,conjecture,
    [--greater(hazard_of_mortality(sk2,sk5),hazard_of_mortality(sk2,sk4)),
     --equal(hazard_of_mortality(sk2,sk4),hazard_of_mortality(sk2,sk3))]).
%--------------------------------------------------------------------------
