%--------------------------------------------------------------------------
% File     : MGT058+1 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : An organization's position cannot be both fragile and robust
% Version  : [Han98] axioms.
% English  : 

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [Kam00]
% Names    : LEMMA 10 [Han98]

% Status   : theorem
% Rating   : 0.22 v2.7.0, 0.33 v2.5.0, 0.17 v2.4.0
% Syntax   : Number of formulae    :   27 (   1 unit)
%            Number of atoms       :   81 (  27 equality)
%            Maximal formula depth :    7 (   4 average)
%            Number of connectives :   58 (   4 ~  ;   4  |;  22  &)
%                                         (   5 <=>;  23 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    9 (   0 propositional; 1-2 arity)
%            Number of functors    :    4 (   3 constant; 0-2 arity)
%            Number of variables   :   67 (   0 singleton;  66 !;   1 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%----Include inequality axioms
include('Axioms/MGT001+0.ax').
include('Axioms/MGT001+0.eq').
%--------------------------------------------------------------------------
input_formula(age_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(age(A,C),age(B,C)) )   )).

input_formula(age_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(age(C,A),age(C,B)) )   )).

input_formula(fragile_position_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & fragile_position(A) )
     => fragile_position(B) )   )).

input_formula(organization_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & organization(A) )
     => organization(B) )   )).

input_formula(positional_advantage_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & positional_advantage(A,C) )
     => positional_advantage(B,C) )   )).

input_formula(positional_advantage_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & positional_advantage(C,A) )
     => positional_advantage(C,B) )   )).

input_formula(robust_position_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & robust_position(A) )
     => robust_position(B) )   )).

%----Problem Axioms
%--- Case: Fragile and robust positions in drifting environments.
%--- Retracting A16!
%----
%----An organization's position is fragile if and only if it does not
%----provide advantage after age `sigma'.
%----
%----Added case:  ( smaller_or_equal(age(X,T),sigma) 
%----            => positional_advantage(X,T) )
input_formula(definition_3,axiom,(
    ! [X] : 
      ( fragile_position(X)
    <=> ! [T] : 
          ( ( smaller_or_equal(age(X,T),sigma)
           => positional_advantage(X,T) )
          & ( greater(age(X,T),sigma)
           => ~ positional_advantage(X,T) ) ) )   )).

%----An organization's position is robust if and only if it provides
%----positional advantage only after age `tau'.
%----
%----Text says fragile_position(X) instead of robust_position(X).
%----Interchanged ~ positional_advantage(X,T) and positional_advantage(X,T).
input_formula(definition_4,axiom,(
    ! [X] : 
      ( robust_position(X)
    <=> ! [T] : 
          ( ( smaller_or_equal(age(X,T),tau)
           => ~ positional_advantage(X,T) )
          & ( greater(age(X,T),tau)
           => positional_advantage(X,T) ) ) )   )).

%----Problem theorems
%----An organization's position cannot be both fragile and robust.
%----From D3-4 (also needs D<, D<=, D>=, MP>com).
%----
%----Requires several additions to the antecedent.
input_formula(lemma_10,conjecture,(
    ! [X] : 
      ( ( organization(X)
        & ? [T0] : equal(age(X,T0),zero)
        & greater_or_equal(sigma,zero)
        & greater_or_equal(tau,zero) )
     => ~ ( fragile_position(X)
          & robust_position(X) ) )   )).
%--------------------------------------------------------------------------
