%--------------------------------------------------------------------------
% File     : MGT061-1 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Conditions for an in reasing hazard of mortality
% Version  : [Han98] axioms.
% English  : The hazard of mortality increases with age for an unendowed 
%            organization with a fragile position  in drifting environments.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [TPTP]
% Names    : 

% Status   : unsatisfiable
% Rating   : 0.09 v2.7.0, 0.17 v2.6.0, 0.22 v2.5.0, 0.33 v2.4.0
% Syntax   : Number of clauses    :   73 (  16 non-Horn;  13 unit;  60 RR)
%            Number of literals   :  193 (  49 equality)
%            Maximal clause size  :    5 (   2 average)
%            Number of predicates :   12 (   0 propositional; 1-3 arity)
%            Number of functors   :   14 (  11 constant; 0-2 arity)
%            Number of variables  :  150 (   5 singleton)
%            Maximal term depth   :    3 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%          : Created with tptp2X -f tptp -t clausify:otter MGT061+1.p 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001-0.ax').
%----Include inequality axioms
include('Axioms/MGT001-0.ax').
include('Axioms/MGT001-0.eq').
%--------------------------------------------------------------------------
input_clause(age_substitution_1_23,axiom,
    [--equal(A,B),
     ++equal(age(A,C),age(B,C))]).

input_clause(age_substitution_2_24,axiom,
    [--equal(A,B),
     ++equal(age(C,A),age(C,B))]).

input_clause(hazard_of_mortality_substitution_1_25,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C))]).

input_clause(hazard_of_mortality_substitution_2_26,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B))]).

input_clause(dissimilar_substitution_1_27,axiom,
    [--equal(A,B),
     --dissimilar(A,C,D),
     ++dissimilar(B,C,D)]).

input_clause(dissimilar_substitution_2_28,axiom,
    [--equal(A,B),
     --dissimilar(C,A,D),
     ++dissimilar(C,B,D)]).

input_clause(dissimilar_substitution_3_29,axiom,
    [--equal(A,B),
     --dissimilar(C,D,A),
     ++dissimilar(C,D,B)]).

input_clause(fragile_position_substitution_1_30,axiom,
    [--equal(A,B),
     --fragile_position(A),
     ++fragile_position(B)]).

input_clause(has_endowment_substitution_1_31,axiom,
    [--equal(A,B),
     --has_endowment(A),
     ++has_endowment(B)]).

input_clause(has_immunity_substitution_1_32,axiom,
    [--equal(A,B),
     --has_immunity(A,C),
     ++has_immunity(B,C)]).

input_clause(has_immunity_substitution_2_33,axiom,
    [--equal(A,B),
     --has_immunity(C,A),
     ++has_immunity(C,B)]).

input_clause(is_aligned_substitution_1_34,axiom,
    [--equal(A,B),
     --is_aligned(A,C),
     ++is_aligned(B,C)]).

input_clause(is_aligned_substitution_2_35,axiom,
    [--equal(A,B),
     --is_aligned(C,A),
     ++is_aligned(C,B)]).

input_clause(organization_substitution_1_36,axiom,
    [--equal(A,B),
     --organization(A),
     ++organization(B)]).

input_clause(positional_advantage_substitution_1_37,axiom,
    [--equal(A,B),
     --positional_advantage(A,C),
     ++positional_advantage(B,C)]).

input_clause(positional_advantage_substitution_2_38,axiom,
    [--equal(A,B),
     --positional_advantage(C,A),
     ++positional_advantage(C,B)]).

input_clause(assumption_1_39,axiom,
    [--organization(A),
     ++has_endowment(A),
     --has_immunity(A,B)]).

input_clause(definition_2_40,axiom,
    [--dissimilar(A,B,C),
     ++organization(A)]).

input_clause(definition_2_41,axiom,
    [--dissimilar(A,B,C),
     ++is_aligned(A,B),
     ++is_aligned(A,C)]).

input_clause(definition_2_42,axiom,
    [--dissimilar(A,B,C),
     --is_aligned(A,B),
     --is_aligned(A,C)]).

input_clause(definition_2_43,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,B),
     ++dissimilar(A,B,C)]).

input_clause(definition_2_44,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,C),
     ++dissimilar(A,B,C)]).

input_clause(definition_2_45,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,C),
     ++dissimilar(A,C,B)]).

input_clause(definition_2_46,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,B),
     ++dissimilar(A,C,B)]).

input_clause(assumption_13_47,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     ++is_aligned(A,B)]).

input_clause(assumption_15_48,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     --greater(age(A,C),sigma),
     ++dissimilar(A,B,C)]).

input_clause(assumption_15_49,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     --dissimilar(A,B,C),
     ++greater(age(A,C),sigma)]).

input_clause(definition_3_50,axiom,
    [--fragile_position(A),
     --smaller_or_equal(age(A,B),sigma),
     ++positional_advantage(A,B)]).

input_clause(definition_3_51,axiom,
    [--fragile_position(A),
     --greater(age(A,B),sigma),
     --positional_advantage(A,B)]).

input_clause(definition_3_52,axiom,
    [++smaller_or_equal(age(A,sk1(A)),sigma),
     ++greater(age(A,sk1(A)),sigma),
     ++fragile_position(A)]).

input_clause(definition_3_53,axiom,
    [++smaller_or_equal(age(A,sk1(A)),sigma),
     ++positional_advantage(A,sk1(A)),
     ++fragile_position(A)]).

input_clause(definition_3_54,axiom,
    [--positional_advantage(A,sk1(A)),
     ++greater(age(A,sk1(A)),sigma),
     ++fragile_position(A)]).

input_clause(definition_3_55,axiom,
    [--positional_advantage(A,sk1(A)),
     ++positional_advantage(A,sk1(A)),
     ++fragile_position(A)]).

input_clause(assumption_17_56,axiom,
    [--organization(A),
     --has_immunity(A,B),
     ++equal(hazard_of_mortality(A,B),very_low)]).

input_clause(assumption_17_57,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     --is_aligned(A,B),
     --positional_advantage(A,B),
     ++equal(hazard_of_mortality(A,B),low)]).

input_clause(assumption_17_58,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++is_aligned(A,B),
     --positional_advantage(A,B),
     ++equal(hazard_of_mortality(A,B),mod1)]).

input_clause(assumption_17_59,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     --is_aligned(A,B),
     ++positional_advantage(A,B),
     ++equal(hazard_of_mortality(A,B),mod2)]).

input_clause(assumption_17_60,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++is_aligned(A,B),
     ++positional_advantage(A,B),
     ++equal(hazard_of_mortality(A,B),high)]).

input_clause(assumption_18a_61,axiom,
    [++greater(high,mod1)]).

input_clause(assumption_18b_62,axiom,
    [++greater(mod1,low)]).

input_clause(assumption_18c_63,axiom,
    [++greater(low,very_low)]).

input_clause(assumption_18d_64,axiom,
    [++greater(high,mod2)]).

input_clause(assumption_18e_65,axiom,
    [++greater(mod2,low)]).

input_clause(theorem_7_66,conjecture,
    [++organization(sk2)]).

input_clause(theorem_7_67,conjecture,
    [++fragile_position(sk2)]).

input_clause(theorem_7_68,conjecture,
    [--has_endowment(sk2)]).

input_clause(theorem_7_69,conjecture,
    [++equal(age(sk2,sk3),zero)]).

input_clause(theorem_7_70,conjecture,
    [++greater(sigma,zero)]).

input_clause(theorem_7_71,conjecture,
    [++smaller_or_equal(age(sk2,sk4),sigma)]).

input_clause(theorem_7_72,conjecture,
    [++greater(age(sk2,sk5),sigma)]).

input_clause(theorem_7_73,conjecture,
    [--greater(hazard_of_mortality(sk2,sk5),hazard_of_mortality(sk2,sk4)),
     --equal(hazard_of_mortality(sk2,sk4),hazard_of_mortality(sk2,sk3))]).
%--------------------------------------------------------------------------
