%--------------------------------------------------------------------------
% File     : MGT062-1 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Condictions for decreasing hazard of mortality
% Version  : [Han98] axioms.
% English  : If environmental drift destroys alignment exactly when advantage 
%            can be gained from occupancy of a robust position, then the 
%            hazard of mortality for an unendowed organization with a robust 
%            position decreases with age.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [TPTP]
% Names    : 

% Status   : unsatisfiable
% Rating   : 0.18 v2.7.0, 0.17 v2.6.0, 0.00 v2.5.0, 0.44 v2.4.0
% Syntax   : Number of clauses    :   71 (  16 non-Horn;  11 unit;  58 RR)
%            Number of literals   :  191 (  50 equality)
%            Maximal clause size  :    5 (   2 average)
%            Number of predicates :   12 (   0 propositional; 1-3 arity)
%            Number of functors   :   15 (  12 constant; 0-2 arity)
%            Number of variables  :  150 (   5 singleton)
%            Maximal term depth   :    3 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%          : Created with tptp2X -f tptp -t clausify:otter MGT062+1.p 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001-0.ax').
%----Include inequality axioms
include('Axioms/MGT001-0.ax').
include('Axioms/MGT001-0.eq').
%--------------------------------------------------------------------------
input_clause(age_substitution_1_23,axiom,
    [--equal(A,B),
     ++equal(age(A,C),age(B,C))]).

input_clause(age_substitution_2_24,axiom,
    [--equal(A,B),
     ++equal(age(C,A),age(C,B))]).

input_clause(hazard_of_mortality_substitution_1_25,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C))]).

input_clause(hazard_of_mortality_substitution_2_26,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B))]).

input_clause(dissimilar_substitution_1_27,axiom,
    [--equal(A,B),
     --dissimilar(A,C,D),
     ++dissimilar(B,C,D)]).

input_clause(dissimilar_substitution_2_28,axiom,
    [--equal(A,B),
     --dissimilar(C,A,D),
     ++dissimilar(C,B,D)]).

input_clause(dissimilar_substitution_3_29,axiom,
    [--equal(A,B),
     --dissimilar(C,D,A),
     ++dissimilar(C,D,B)]).

input_clause(has_endowment_substitution_1_30,axiom,
    [--equal(A,B),
     --has_endowment(A),
     ++has_endowment(B)]).

input_clause(has_immunity_substitution_1_31,axiom,
    [--equal(A,B),
     --has_immunity(A,C),
     ++has_immunity(B,C)]).

input_clause(has_immunity_substitution_2_32,axiom,
    [--equal(A,B),
     --has_immunity(C,A),
     ++has_immunity(C,B)]).

input_clause(is_aligned_substitution_1_33,axiom,
    [--equal(A,B),
     --is_aligned(A,C),
     ++is_aligned(B,C)]).

input_clause(is_aligned_substitution_2_34,axiom,
    [--equal(A,B),
     --is_aligned(C,A),
     ++is_aligned(C,B)]).

input_clause(organization_substitution_1_35,axiom,
    [--equal(A,B),
     --organization(A),
     ++organization(B)]).

input_clause(positional_advantage_substitution_1_36,axiom,
    [--equal(A,B),
     --positional_advantage(A,C),
     ++positional_advantage(B,C)]).

input_clause(positional_advantage_substitution_2_37,axiom,
    [--equal(A,B),
     --positional_advantage(C,A),
     ++positional_advantage(C,B)]).

input_clause(robust_position_substitution_1_38,axiom,
    [--equal(A,B),
     --robust_position(A),
     ++robust_position(B)]).

input_clause(assumption_1_39,axiom,
    [--organization(A),
     ++has_endowment(A),
     --has_immunity(A,B)]).

input_clause(definition_2_40,axiom,
    [--dissimilar(A,B,C),
     ++organization(A)]).

input_clause(definition_2_41,axiom,
    [--dissimilar(A,B,C),
     ++is_aligned(A,B),
     ++is_aligned(A,C)]).

input_clause(definition_2_42,axiom,
    [--dissimilar(A,B,C),
     --is_aligned(A,B),
     --is_aligned(A,C)]).

input_clause(definition_2_43,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,B),
     ++dissimilar(A,B,C)]).

input_clause(definition_2_44,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,C),
     ++dissimilar(A,B,C)]).

input_clause(definition_2_45,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,C),
     ++dissimilar(A,C,B)]).

input_clause(definition_2_46,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,B),
     ++dissimilar(A,C,B)]).

input_clause(assumption_13_47,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     ++is_aligned(A,B)]).

input_clause(assumption_15_48,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     --greater(age(A,C),sigma),
     ++dissimilar(A,B,C)]).

input_clause(assumption_15_49,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     --dissimilar(A,B,C),
     ++greater(age(A,C),sigma)]).

input_clause(definition_4_50,axiom,
    [--robust_position(A),
     --smaller_or_equal(age(A,B),tau),
     --positional_advantage(A,B)]).

input_clause(definition_4_51,axiom,
    [--robust_position(A),
     --greater(age(A,B),tau),
     ++positional_advantage(A,B)]).

input_clause(definition_4_52,axiom,
    [++smaller_or_equal(age(A,sk1(A)),tau),
     ++greater(age(A,sk1(A)),tau),
     ++robust_position(A)]).

input_clause(definition_4_53,axiom,
    [++smaller_or_equal(age(A,sk1(A)),tau),
     --positional_advantage(A,sk1(A)),
     ++robust_position(A)]).

input_clause(definition_4_54,axiom,
    [++positional_advantage(A,sk1(A)),
     ++greater(age(A,sk1(A)),tau),
     ++robust_position(A)]).

input_clause(definition_4_55,axiom,
    [++positional_advantage(A,sk1(A)),
     --positional_advantage(A,sk1(A)),
     ++robust_position(A)]).

input_clause(assumption_17_56,axiom,
    [--organization(A),
     --has_immunity(A,B),
     ++equal(hazard_of_mortality(A,B),very_low)]).

input_clause(assumption_17_57,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     --is_aligned(A,B),
     --positional_advantage(A,B),
     ++equal(hazard_of_mortality(A,B),low)]).

input_clause(assumption_17_58,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++is_aligned(A,B),
     --positional_advantage(A,B),
     ++equal(hazard_of_mortality(A,B),mod1)]).

input_clause(assumption_17_59,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     --is_aligned(A,B),
     ++positional_advantage(A,B),
     ++equal(hazard_of_mortality(A,B),mod2)]).

input_clause(assumption_17_60,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++is_aligned(A,B),
     ++positional_advantage(A,B),
     ++equal(hazard_of_mortality(A,B),high)]).

input_clause(assumption_19_61,axiom,
    [++greater(mod2,mod1)]).

input_clause(theorem_8_62,conjecture,
    [++organization(sk2)]).

input_clause(theorem_8_63,conjecture,
    [++robust_position(sk2)]).

input_clause(theorem_8_64,conjecture,
    [--has_endowment(sk2)]).

input_clause(theorem_8_65,conjecture,
    [++equal(age(sk2,sk3),zero)]).

input_clause(theorem_8_66,conjecture,
    [++greater(sigma,zero)]).

input_clause(theorem_8_67,conjecture,
    [++greater(tau,zero)]).

input_clause(theorem_8_68,conjecture,
    [++equal(sigma,tau)]).

input_clause(theorem_8_69,conjecture,
    [++smaller_or_equal(age(sk2,sk4),sigma)]).

input_clause(theorem_8_70,conjecture,
    [++greater(age(sk2,sk5),sigma)]).

input_clause(theorem_8_71,conjecture,
    [--smaller(hazard_of_mortality(sk2,sk5),hazard_of_mortality(sk2,sk4)),
     --equal(hazard_of_mortality(sk2,sk4),hazard_of_mortality(sk2,sk3))]).
%--------------------------------------------------------------------------
