%--------------------------------------------------------------------------
% File     : MGT064-1 : TPTP v2.7.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Conditions for a decreasing then increasing hazard of mortality
% Version  : [Han98] axioms.
% English  : If advantage can be gained from occupancy of a robust position
%            before environmental drift destroys alignment, then the hazard 
%            of mortality for an unendowed organization with a robust 
%            position initially decreases with age and then rises with
%            further aging but remains below the initial level.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [TPTP]
% Names    : 

% Status   : unsatisfiable
% Rating   : 0.55 v2.7.0, 0.42 v2.6.0, 0.67 v2.5.0, 0.78 v2.4.0
% Syntax   : Number of clauses    :   85 (  20 non-Horn;  18 unit;  72 RR)
%            Number of literals   :  223 (  49 equality)
%            Maximal clause size  :    5 (   2 average)
%            Number of predicates :   12 (   0 propositional; 1-3 arity)
%            Number of functors   :   18 (  14 constant; 0-2 arity)
%            Number of variables  :  159 (   5 singleton)
%            Maximal term depth   :    3 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%          : Created with tptp2X -f tptp -t clausify:otter MGT064+1.p 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001-0.ax').
%----Include inequality axioms
include('Axioms/MGT001-0.ax').
include('Axioms/MGT001-0.eq').
%--------------------------------------------------------------------------
input_clause(age_substitution_1_23,axiom,
    [--equal(A,B),
     ++equal(age(A,C),age(B,C))]).

input_clause(age_substitution_2_24,axiom,
    [--equal(A,B),
     ++equal(age(C,A),age(C,B))]).

input_clause(hazard_of_mortality_substitution_1_25,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C))]).

input_clause(hazard_of_mortality_substitution_2_26,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B))]).

input_clause(dissimilar_substitution_1_27,axiom,
    [--equal(A,B),
     --dissimilar(A,C,D),
     ++dissimilar(B,C,D)]).

input_clause(dissimilar_substitution_2_28,axiom,
    [--equal(A,B),
     --dissimilar(C,A,D),
     ++dissimilar(C,B,D)]).

input_clause(dissimilar_substitution_3_29,axiom,
    [--equal(A,B),
     --dissimilar(C,D,A),
     ++dissimilar(C,D,B)]).

input_clause(has_endowment_substitution_1_30,axiom,
    [--equal(A,B),
     --has_endowment(A),
     ++has_endowment(B)]).

input_clause(has_immunity_substitution_1_31,axiom,
    [--equal(A,B),
     --has_immunity(A,C),
     ++has_immunity(B,C)]).

input_clause(has_immunity_substitution_2_32,axiom,
    [--equal(A,B),
     --has_immunity(C,A),
     ++has_immunity(C,B)]).

input_clause(is_aligned_substitution_1_33,axiom,
    [--equal(A,B),
     --is_aligned(A,C),
     ++is_aligned(B,C)]).

input_clause(is_aligned_substitution_2_34,axiom,
    [--equal(A,B),
     --is_aligned(C,A),
     ++is_aligned(C,B)]).

input_clause(organization_substitution_1_35,axiom,
    [--equal(A,B),
     --organization(A),
     ++organization(B)]).

input_clause(positional_advantage_substitution_1_36,axiom,
    [--equal(A,B),
     --positional_advantage(A,C),
     ++positional_advantage(B,C)]).

input_clause(positional_advantage_substitution_2_37,axiom,
    [--equal(A,B),
     --positional_advantage(C,A),
     ++positional_advantage(C,B)]).

input_clause(robust_position_substitution_1_38,axiom,
    [--equal(A,B),
     --robust_position(A),
     ++robust_position(B)]).

input_clause(definition_1_39,axiom,
    [--has_endowment(A),
     ++organization(A)]).

input_clause(definition_1_40,axiom,
    [--has_endowment(A),
     --smaller_or_equal(age(A,B),eta),
     ++has_immunity(A,B)]).

input_clause(definition_1_41,axiom,
    [--has_endowment(A),
     --greater(age(A,B),eta),
     --has_immunity(A,B)]).

input_clause(definition_1_42,axiom,
    [--organization(A),
     ++smaller_or_equal(age(A,sk1(A)),eta),
     ++greater(age(A,sk1(A)),eta),
     ++has_endowment(A)]).

input_clause(definition_1_43,axiom,
    [--organization(A),
     ++smaller_or_equal(age(A,sk1(A)),eta),
     ++has_immunity(A,sk1(A)),
     ++has_endowment(A)]).

input_clause(definition_1_44,axiom,
    [--organization(A),
     --has_immunity(A,sk1(A)),
     ++greater(age(A,sk1(A)),eta),
     ++has_endowment(A)]).

input_clause(definition_1_45,axiom,
    [--organization(A),
     --has_immunity(A,sk1(A)),
     ++has_immunity(A,sk1(A)),
     ++has_endowment(A)]).

input_clause(assumption_1_46,axiom,
    [--organization(A),
     ++has_endowment(A),
     --has_immunity(A,B)]).

input_clause(definition_2_47,axiom,
    [--dissimilar(A,B,C),
     ++organization(A)]).

input_clause(definition_2_48,axiom,
    [--dissimilar(A,B,C),
     ++is_aligned(A,B),
     ++is_aligned(A,C)]).

input_clause(definition_2_49,axiom,
    [--dissimilar(A,B,C),
     --is_aligned(A,B),
     --is_aligned(A,C)]).

input_clause(definition_2_50,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,B),
     ++dissimilar(A,B,C)]).

input_clause(definition_2_51,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,C),
     ++dissimilar(A,B,C)]).

input_clause(definition_2_52,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,C),
     ++dissimilar(A,C,B)]).

input_clause(definition_2_53,axiom,
    [--organization(A),
     --is_aligned(A,B),
     ++is_aligned(A,B),
     ++dissimilar(A,C,B)]).

input_clause(assumption_13_54,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     ++is_aligned(A,B)]).

input_clause(assumption_15_55,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     --greater(age(A,C),sigma),
     ++dissimilar(A,B,C)]).

input_clause(assumption_15_56,axiom,
    [--organization(A),
     --equal(age(A,B),zero),
     --dissimilar(A,B,C),
     ++greater(age(A,C),sigma)]).

input_clause(definition_4_57,axiom,
    [--robust_position(A),
     --smaller_or_equal(age(A,B),tau),
     --positional_advantage(A,B)]).

input_clause(definition_4_58,axiom,
    [--robust_position(A),
     --greater(age(A,B),tau),
     ++positional_advantage(A,B)]).

input_clause(definition_4_59,axiom,
    [++smaller_or_equal(age(A,sk2(A)),tau),
     ++greater(age(A,sk2(A)),tau),
     ++robust_position(A)]).

input_clause(definition_4_60,axiom,
    [++smaller_or_equal(age(A,sk2(A)),tau),
     --positional_advantage(A,sk2(A)),
     ++robust_position(A)]).

input_clause(definition_4_61,axiom,
    [++positional_advantage(A,sk2(A)),
     ++greater(age(A,sk2(A)),tau),
     ++robust_position(A)]).

input_clause(definition_4_62,axiom,
    [++positional_advantage(A,sk2(A)),
     --positional_advantage(A,sk2(A)),
     ++robust_position(A)]).

input_clause(assumption_17_63,axiom,
    [--organization(A),
     --has_immunity(A,B),
     ++equal(hazard_of_mortality(A,B),very_low)]).

input_clause(assumption_17_64,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     --is_aligned(A,B),
     --positional_advantage(A,B),
     ++equal(hazard_of_mortality(A,B),low)]).

input_clause(assumption_17_65,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++is_aligned(A,B),
     --positional_advantage(A,B),
     ++equal(hazard_of_mortality(A,B),mod1)]).

input_clause(assumption_17_66,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     --is_aligned(A,B),
     ++positional_advantage(A,B),
     ++equal(hazard_of_mortality(A,B),mod2)]).

input_clause(assumption_17_67,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++is_aligned(A,B),
     ++positional_advantage(A,B),
     ++equal(hazard_of_mortality(A,B),high)]).

input_clause(assumption_18a_68,axiom,
    [++greater(high,mod1)]).

input_clause(assumption_18b_69,axiom,
    [++greater(mod1,low)]).

input_clause(assumption_18c_70,axiom,
    [++greater(low,very_low)]).

input_clause(assumption_18d_71,axiom,
    [++greater(high,mod2)]).

input_clause(assumption_18e_72,axiom,
    [++greater(mod2,low)]).

input_clause(assumption_19_73,axiom,
    [++greater(mod2,mod1)]).

input_clause(theorem_10_74,conjecture,
    [++organization(sk3)]).

input_clause(theorem_10_75,conjecture,
    [++robust_position(sk3)]).

input_clause(theorem_10_76,conjecture,
    [--has_endowment(sk3)]).

input_clause(theorem_10_77,conjecture,
    [++equal(age(sk3,sk4),zero)]).

input_clause(theorem_10_78,conjecture,
    [++greater(sigma,zero)]).

input_clause(theorem_10_79,conjecture,
    [++greater(tau,zero)]).

input_clause(theorem_10_80,conjecture,
    [++greater(sigma,tau)]).

input_clause(theorem_10_81,conjecture,
    [++smaller_or_equal(age(sk3,sk5),tau)]).

input_clause(theorem_10_82,conjecture,
    [++greater(age(sk3,sk6),tau)]).

input_clause(theorem_10_83,conjecture,
    [++smaller_or_equal(age(sk3,sk6),sigma)]).

input_clause(theorem_10_84,conjecture,
    [++greater(age(sk3,sk7),sigma)]).

input_clause(theorem_10_85,conjecture,
    [--smaller(hazard_of_mortality(sk3,sk6),hazard_of_mortality(sk3,sk7)),
     --smaller(hazard_of_mortality(sk3,sk7),hazard_of_mortality(sk3,sk5)),
     --equal(hazard_of_mortality(sk3,sk5),hazard_of_mortality(sk3,sk4))]).
%--------------------------------------------------------------------------
