%--------------------------------------------------------------------------
% File     : PLA028+1 : TPTP v2.7.0. Bugfixed v2.5.0.
% Domain   : Planning
% Problem  : Blocks A, B => A/B
% Version  : [Bau99] axioms.
% English  :

% Refs     : [Bau99] Baumgartner (1999), FTP'2000 - Problem Sets
%            [KS96]  Kautz & Selman (1996), Pushing the Envelope: Planning,
%            [KS92]  Kautz & Selman (1992), Planning as Satisfiability
% Source   : [Bau99]
% Names    : tiny [Bau99]

% Status   : satisfiable
% Rating   : 0.50 v2.7.0, 0.00 v2.6.0, 0.33 v2.5.0
% Syntax   : Number of formulae    :   45 (  16 unit)
%            Number of atoms       :  153 (   0 equality)
%            Maximal formula depth :    9 (   4 average)
%            Number of connectives :  133 (  25 ~  ;   6  |;  45  &)
%                                         (   0 <=>;  57 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :   12 (   0 propositional; 1-3 arity)
%            Number of functors    :    5 (   4 constant; 0-1 arity)
%            Number of variables   :   70 (   0 singleton;  70 !;   0 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments :
% Bugfixes : v2.5.0 - Combined multiple conjecture formulae.
%--------------------------------------------------------------------------
%----Include blocks world axioms
include('Axioms/PLA002+0.ax').
%--------------------------------------------------------------------------
input_formula(different_not_equal,hypothesis,(
    ! [Y,X] : 
      ( ( different(X,Y)
        | different(Y,X) )
     => neq(X,Y) )   )).

input_formula(block_1_not_block_2,hypothesis,(
    different(block_1,block_2)   )).

input_formula(block_1_not_table,hypothesis,(
    different(block_1,table)   )).

input_formula(block_2_not_table,hypothesis,(
    different(block_2,table)   )).

%----Blocks in the world:
input_formula(block_1,hypothesis,(
    a_block(block_1)   )).

input_formula(block_2,hypothesis,(
    a_block(block_2)   )).

input_formula(table,hypothesis,(
    a_block(table)   )).

%----Blocks are further distinguished in 'fixed' (which cannot be moved)
%----'nonfixed'. 
input_formula(fixed_table,hypothesis,(
    fixed(table)   )).

input_formula(nonfixed_block_1,hypothesis,(
    nonfixed(block_1)   )).

input_formula(nonfixed_block_2,hypothesis,(
    nonfixed(block_2)   )).

%----Give here a list 0..N of timepoints in order to generate the states 
%----of time N. Have to enumerate at least up to N in order to find a plan 
%----of length N
input_formula(time_0,hypothesis,(
    time(time_0)   )).

input_formula(time_1,hypothesis,(
    time(s(time_0))   )).

%----At any time, have some source, destination and object:
input_formula(some_source,hypothesis,(
    ! [I] : 
      ( time(I)
     => ( source(block_1,I)
        | source(block_2,I)
        | source(table,I) ) )   )).

input_formula(some_destination,hypothesis,(
    ! [I] : 
      ( time(I)
     => ( destination(block_1,I)
        | destination(block_2,I)
        | destination(table,I) ) )   )).

input_formula(some_object,hypothesis,(
    ! [I] : 
      ( time(I)
     => ( object(block_1,I)
        | object(block_2,I) ) )   )).

%----Initial state: both blocks on table
input_formula(initial_1_on_table,hypothesis,(
    on(block_1,table,time_0)   )).

input_formula(initial_clear_1,hypothesis,(
    clear(block_1,time_0)   )).

input_formula(initial_2_on_table,hypothesis,(
    on(block_2,table,time_0)   )).

input_formula(initial_clear_2,hypothesis,(
    clear(block_2,time_0)   )).

%----Final state
input_formula(goal_time_1,hypothesis,(
    goal_time(s(time_0))   )).

input_formula(goal_state,conjecture,(
    ! [S] : 
      ( goal_time(S)
     => ( clear(block_1,S)
        & on(block_1,block_2,S)
        & on(block_2,table,S) ) )   )).
%--------------------------------------------------------------------------
