%--------------------------------------------------------------------------
% File     : RNG010-7 : TPTP v2.7.0. Bugfixed v2.3.0.
% Domain   : Ring Theory (Right alternative)
% Problem  : Skew symmetry of the auxilliary function
% Version  : [Ste87] (equality) axioms : Augmented.
% English  : The three Moufang identities imply the skew symmetry 
%            of s(W,X,Y,Z) = (W*X,Y,Z) - X*(W,Y,Z) - (X,Y,Z)*W.
%            Recall that skew symmetry means that the function sign 
%            changes when any two arguments are swapped. This problem 
%            proves the case for swapping the first two arguments.

% Refs     : [Ste87] Stevens (1987), Some Experiments in Nonassociative Rin
% Source   : [TPTP]
% Names    : 

% Status   : unknown
% Rating   : 1.00 v2.3.0
% Syntax   : Number of clauses    :   44 (   0 non-Horn;  28 unit;   4 RR)
%            Number of literals   :   61 (  61 equality)
%            Maximal clause size  :    3 (   1 average)
%            Number of predicates :    1 (   0 propositional; 2-2 arity)
%            Number of functors   :   11 (   5 constant; 0-4 arity)
%            Number of variables  :  116 (   2 singleton)
%            Maximal term depth   :    6 (   2 average)

% Comments : Extra lemmas added to help the ITP prover.
% Bugfixes : v2.3.0 - Clause prove_skew_symmetry fixed.
%          : v2.3.0 - Left alternative law added in.
%          : v2.3.0 - Clauses right_moufang and left_moufang fixed.
%--------------------------------------------------------------------------
%----Include equality axioms 
include('Axioms/EQU001-0.ax').
%----Include nonassociative ring axioms.
include('Axioms/RNG003-0.ax').
%--------------------------------------------------------------------------
%----The next 7 clauses are extra lemmas which Stevens found useful 
input_clause(product_of_inverses,axiom,
    [++equal(multiply(additive_inverse(X),additive_inverse(Y)),
multiply(X,Y))]).

input_clause(inverse_product1,axiom,
    [++equal(multiply(additive_inverse(X),Y),additive_inverse(
multiply(X,Y)))]).

input_clause(inverse_product2,axiom,
    [++equal(multiply(X,additive_inverse(Y)),additive_inverse(
multiply(X,Y)))]).

input_clause(distributivity_of_difference1,axiom,
    [++equal(multiply(X,add(Y,additive_inverse(Z))),add(multiply(X,Y),
additive_inverse(multiply(X,Z))))]).

input_clause(distributivity_of_difference2,axiom,
    [++equal(multiply(add(X,additive_inverse(Y)),Z),add(multiply(X,Z),
additive_inverse(multiply(Y,Z))))]).

input_clause(distributivity_of_difference3,axiom,
    [++equal(multiply(additive_inverse(X),add(Y,Z)),add(
additive_inverse(multiply(X,Y)),additive_inverse(multiply(X,Z))))]).

input_clause(distributivity_of_difference4,axiom,
    [++equal(multiply(add(X,Y),additive_inverse(Z)),add(
additive_inverse(multiply(X,Z)),additive_inverse(multiply(Y,Z))))]).

%----Definition of s 
input_clause(defines_s,axiom,
    [++equal(s(W,X,Y,Z),add(add(associator(multiply(W,X),Y,Z),
additive_inverse(multiply(X,associator(W,Y,Z)))),additive_inverse(
multiply(associator(X,Y,Z),W))))]).

input_clause(s_substitutivity1,axiom,
    [--equal(S,T),
     ++equal(s(S,U,V,W),s(T,U,V,W))]).

input_clause(s_substitutivity2,axiom,
    [--equal(X,Y),
     ++equal(s(Z,X,A1,B1),s(Z,Y,A1,B1))]).

input_clause(s_substitutivity3,axiom,
    [--equal(C1,D1),
     ++equal(s(E1,F1,C1,G1),s(E1,F1,D1,G1))]).

input_clause(s_substitutivity4,axiom,
    [--equal(H1,I1),
     ++equal(s(J1,K1,L1,H1),s(J1,K1,L1,I1))]).

%----Right Moufang
input_clause(right_moufang,hypothesis,
    [++equal(multiply(Z,multiply(X,multiply(Y,X))),
multiply(multiply(multiply(Z,X),Y),X))]).

%----Left Moufang
input_clause(left_moufang,hypothesis,
    [++equal(multiply(multiply(X,multiply(Y,X)),Z),
multiply(X,multiply(Y,multiply(X,Z))))]).

input_clause(middle_moufang,hypothesis,
    [++equal(multiply(multiply(X,Y),multiply(Z,X)),multiply(multiply(
X,multiply(Y,Z)),X))]).

input_clause(prove_skew_symmetry,conjecture,
    [--equal(s(a,b,c,d),additive_inverse(s(b,a,c,d)))]).
%--------------------------------------------------------------------------
